@@ -23,14 +23,16 @@ using namespace std;
 Database::Database(void):
   m_db(NULL), m_begin(NULL), m_commit(NULL), m_rollback(NULL), m_insert_recipe(NULL),
   m_add_category(NULL), m_recipe_category(NULL), m_add_ingredient(NULL), m_recipe_ingredient(NULL),
-  m_get_header(NULL), m_get_categories(NULL), m_get_ingredients(NULL), m_add_instruction(NULL),
-  m_get_instructions(NULL), m_add_ingredient_section(NULL), m_get_ingredient_section(NULL),
+  m_get_header(NULL), m_get_categories(NULL), m_category_and_count_list(NULL), m_get_ingredients(NULL),
+  m_add_instruction(NULL), m_get_instructions(NULL), m_add_ingredient_section(NULL), m_get_ingredient_section(NULL),
   m_add_instruction_section(NULL), m_get_instruction_section(NULL), m_count_selected(NULL), m_get_info(NULL),
   m_select_title(NULL), m_category_list(NULL), m_select_category(NULL), m_select_no_category(NULL),
   m_select_ingredient(NULL), m_select_no_ingredient(NULL), m_delete_recipe(NULL), m_delete_categories(NULL),
   m_delete_ingredients(NULL), m_delete_instructions(NULL), m_delete_ingredient_sections(NULL),
   m_delete_instruction_sections(NULL), m_delete_selection(NULL), m_clean_categories(NULL), m_clean_ingredients(NULL),
-  m_select_recipe(NULL), m_remove_recipe_category(NULL)
+  m_select_recipe(NULL), m_remove_recipe_category(NULL), m_rename_category(NULL), m_get_category_id(NULL),
+  m_merge_category(NULL), m_delete_category(NULL), m_delete_recipe_category(NULL), m_count_recipes_in_category(NULL),
+  m_get_language(NULL), m_delete_language(NULL), m_set_language(NULL)
 {
 }
 
@@ -45,6 +47,7 @@ Database::~Database(void) {
   sqlite3_finalize(m_recipe_ingredient);
   sqlite3_finalize(m_get_header);
   sqlite3_finalize(m_get_categories);
+  sqlite3_finalize(m_category_and_count_list);
   sqlite3_finalize(m_get_ingredients);
   sqlite3_finalize(m_add_instruction);
   sqlite3_finalize(m_get_instructions);
@@ -66,10 +69,19 @@ Database::~Database(void) {
   sqlite3_finalize(m_delete_ingredient_sections);
   sqlite3_finalize(m_delete_instruction_sections);
   sqlite3_finalize(m_delete_selection);
+  sqlite3_finalize(m_rename_category);
   sqlite3_finalize(m_clean_categories);
   sqlite3_finalize(m_clean_ingredients);
   sqlite3_finalize(m_select_recipe);
   sqlite3_finalize(m_remove_recipe_category);
+  sqlite3_finalize(m_get_category_id);
+  sqlite3_finalize(m_merge_category);
+  sqlite3_finalize(m_delete_category);
+  sqlite3_finalize(m_delete_recipe_category);
+  sqlite3_finalize(m_count_recipes_in_category);
+  sqlite3_finalize(m_get_language);
+  sqlite3_finalize(m_delete_language);
+  sqlite3_finalize(m_set_language);
   sqlite3_close(m_db);
 }
 
@@ -112,6 +124,10 @@ void Database::open(const char *filename) {
   result = sqlite3_prepare_v2(m_db, "SELECT name FROM categories, category WHERE recipeid = ?001 AND id = categoryid ORDER BY name;",
                               -1, &m_get_categories, NULL);
   check(result, "Error preparing statement for fetching recipe categories: ");
+  result = sqlite3_prepare_v2(m_db, "SELECT name, COUNT(recipeid) FROM categories LEFT JOIN category ON id = categoryid "
+                              "GROUP BY name ORDER BY name;",
+                              -1, &m_category_and_count_list, NULL);
+  check(result, "Error preparing statement for fetching recipe categories and recipe counts: ");
   result = sqlite3_prepare_v2(m_db, "SELECT amountint, amountnum, amountdenom, amountfloat, unit, name "
                               "FROM ingredient, ingredients WHERE recipeid = ?001 AND ingredientid = ingredients.id ORDER BY line;",
                               -1, &m_get_ingredients, NULL);
@@ -177,6 +193,16 @@ void Database::open(const char *filename) {
   check(result, "Error preparing statement for deleting instruction sections: ");
   result = sqlite3_prepare_v2(m_db, "DELETE FROM selection WHERE id = ?001;", -1, &m_delete_selection, NULL);
   check(result, "Error preparing statement for deleting recipe from selection: ");
+  result = sqlite3_prepare_v2(m_db, "UPDATE categories SET name = ?002 WHERE name = ?001;", -1, &m_rename_category, NULL);
+  check(result, "Error preparing statement for renaming category: ");
+  result = sqlite3_prepare_v2(m_db, "SELECT id FROM categories WHERE name = ?001;", -1, &m_get_category_id, NULL);
+  check(result, "Error preparing statement for getting category id: ");
+  result = sqlite3_prepare_v2(m_db, "UPDATE OR REPLACE category SET categoryid = ?002 WHERE categoryid = ?001;", -1, &m_merge_category, NULL);
+  check(result, "Error preparing statement for merging categories: ");
+  result = sqlite3_prepare_v2(m_db, "DELETE FROM categories WHERE id = ?001;", -1, &m_delete_category, NULL);
+  check(result, "Error preparing statement for deleting category: ");
+  result = sqlite3_prepare_v2(m_db, "DELETE FROM category WHERE categoryid = ?001;", -1, &m_delete_recipe_category, NULL);
+  check(result, "Error preparing statement for deleting recipe category: ");
   result = sqlite3_prepare_v2(m_db, "DELETE FROM categories WHERE id NOT IN (SELECT categoryid FROM category);", -1,
                               &m_clean_categories, NULL);
   check(result, "Error preparing statement for cleaning categories: ");
@@ -188,6 +214,18 @@ void Database::open(const char *filename) {
   result = sqlite3_prepare_v2(m_db, "DELETE FROM category WHERE recipeid = ?001 AND categoryid IN (SELECT id FROM categories "
                               "WHERE name = ?002);", -1, &m_remove_recipe_category, NULL);
   check(result, "Error preparing statement for removing category from recipe: ");
+  result = sqlite3_prepare_v2(m_db, "SELECT COUNT(recipeid) FROM category, categories WHERE categoryid = id AND name = ?001;",
+                              -1, &m_count_recipes_in_category, NULL);
+  check(result, "Error preparing statement for removing category from recipe: ");
+  result = sqlite3_prepare_v2(m_db, "SELECT language FROM locale;",
+                              -1, &m_get_language, NULL);
+  check(result, "Error preparing statement for getting language: ");
+  result = sqlite3_prepare_v2(m_db, "DELETE FROM locale;",
+                              -1, &m_delete_language, NULL);
+  check(result, "Error preparing statement for deleting language: ");
+  result = sqlite3_prepare_v2(m_db, "INSERT INTO locale VALUES(?001);",
+                              -1, &m_set_language, NULL);
+  check(result, "Error preparing statement for setting language: ");
 }
 
 int Database::user_version(void) {
@@ -209,9 +247,8 @@ void Database::pragmas(void) {
   check(result, "Error setting cache size: ");
 }
 
-void Database::create(void) {
+void Database::create_version_1(void) {
   int result = sqlite3_exec(m_db,
-    "PRAGMA user_version = 1;\n"
     "BEGIN;\n"
     "CREATE TABLE recipes(id INTEGER PRIMARY KEY, title VARCHAR(60) NOT NULL, servings INTEGER NOT NULL, "
     "servingsunit VARCHAR(40) NOT NULL);\n"
@@ -229,16 +266,30 @@ void Database::create(void) {
     "PRIMARY KEY (recipeid, line), FOREIGN KEY(recipeid) REFERENCES recipes(id));\n"
     "CREATE TABLE instructionsection(recipeid INTEGER NOT NULL, line INTEGER NOT NULL, title VARCHAR(60) NOT NULL, "
     "PRIMARY KEY (recipeid, line), FOREIGN KEY(recipeid) REFERENCES recipes(id));\n"
-    "COMMIT;\n",
+    "COMMIT;\n"
+    "PRAGMA user_version = 1;\n",
     NULL, NULL, NULL);
   check(result, "Error creating database tables: ");
 }
 
+void Database::migrate_version_1_to_version_2(void)
+{
+  int result = sqlite3_exec(m_db,
+    "BEGIN;\n"
+    "CREATE TABLE locale(language VARCHAR(2) NOT NULL);\n"
+    "COMMIT;\n"
+    "PRAGMA user_version = 2;\n",
+    NULL, NULL, NULL);
+  check(result, "Error migrating database to version 2: ");
+}
+
 void Database::migrate(void) {
   int version = user_version();
   if (version <= 0)
-    create();
-  if (version > 1) {
+    create_version_1();
+  if (version <= 1)
+    migrate_version_1_to_version_2();
+  if (version > 2) {
     ostringstream s;
     s << "Database version " << version << " was created by more recent release of software.";
     throw database_exception(s.str());
@@ -266,16 +317,29 @@ void Database::rollback(void) {
   check(result, "Error resetting rollback transaction statement: ");
 }
 
+void Database::add_category(const char *name) {
+  int result = sqlite3_bind_text(m_add_category, 1, name, -1, SQLITE_STATIC);
+  check(result, "Error binding category name: ");
+  result = sqlite3_step(m_add_category);
+  check(result, "Error adding category: ");
+  result = sqlite3_reset(m_add_category);
+  check(result, "Error resetting category adding statement: ");
+}
+
+#include <iostream>
+
 sqlite3_int64 Database::insert_recipe(Recipe &recipe) {
   int c;
   assert(m_insert_recipe);
   int result;
   // Add recipe header.
-  result = sqlite3_bind_text(m_insert_recipe, 1, recipe.title().c_str(), -1, SQLITE_STATIC);
+  string title = recipe.title();
+  result = sqlite3_bind_text(m_insert_recipe, 1, recipe.title_c_str(), -1, SQLITE_STATIC);
   check(result, "Error binding recipe title: ");
   result = sqlite3_bind_int(m_insert_recipe, 2, recipe.servings());
   check(result, "Error binding recipe servings: ");
-  result = sqlite3_bind_text(m_insert_recipe, 3, recipe.servings_unit().c_str(), -1, SQLITE_STATIC);
+  string servings_unit = recipe.servings_unit();
+  result = sqlite3_bind_text(m_insert_recipe, 3, recipe.servings_unit_c_str(), -1, SQLITE_STATIC);
   check(result, "Error binding recipe servings unit: ");
   result = sqlite3_step(m_insert_recipe);
   check(result, "Error executing insert statement: ");
@@ -284,14 +348,9 @@ sqlite3_int64 Database::insert_recipe(Recipe &recipe) {
   // Get recipe id.
   sqlite3_int64 recipe_id = sqlite3_last_insert_rowid(m_db);
   // Add categories.
-  for (vector<string>::iterator category=recipe.categories().begin(); category!=recipe.categories().end(); category++) {
+  for (set<string>::iterator category=recipe.categories().begin(); category!=recipe.categories().end(); category++) {
     // Create category.
-    result = sqlite3_bind_text(m_add_category, 1, category->c_str(), -1, SQLITE_STATIC);
-    check(result, "Error binding category name: ");
-    result = sqlite3_step(m_add_category);
-    check(result, "Error adding category: ");
-    result = sqlite3_reset(m_add_category);
-    check(result, "Error resetting category adding statement: ");
+    add_category(category->c_str());
     // Add recipe to category.
     result = sqlite3_bind_int64(m_recipe_category, 1, recipe_id);
     check(result, "Error binding recipe id: ");
@@ -306,7 +365,7 @@ sqlite3_int64 Database::insert_recipe(Recipe &recipe) {
   c = 1;
   for (vector<Ingredient>::iterator ingredient=recipe.ingredients().begin(); ingredient!=recipe.ingredients().end(); ingredient++) {
     // Create ingredient.
-    result = sqlite3_bind_text(m_add_ingredient, 1, ingredient->text().c_str(), -1, SQLITE_STATIC);
+    result = sqlite3_bind_text(m_add_ingredient, 1, ingredient->text_c_str(), -1, SQLITE_STATIC);
     check(result, "Error binding ingredient: ");
     result = sqlite3_step(m_add_ingredient);
     check(result, "Error adding ingredient: ");
@@ -325,9 +384,11 @@ sqlite3_int64 Database::insert_recipe(Recipe &recipe) {
     check(result, "Error binding ingredient amount denominator: ");
     result = sqlite3_bind_double(m_recipe_ingredient, 6, ingredient->amount_float());
     check(result, "Error binding ingredient floating-point amount: ");
-    result = sqlite3_bind_text(m_recipe_ingredient, 7, ingredient->unit().c_str(), -1, SQLITE_STATIC);
+    string unit = ingredient->unit();
+    result = sqlite3_bind_text(m_recipe_ingredient, 7, ingredient->unit_c_str(), -1, SQLITE_STATIC);
     check(result, "Error binding ingredient unit: ");
-    result = sqlite3_bind_text(m_recipe_ingredient, 8, ingredient->text().c_str(), -1, SQLITE_STATIC);
+    string text = ingredient->text();
+    result = sqlite3_bind_text(m_recipe_ingredient, 8, ingredient->text_c_str(), -1, SQLITE_STATIC);
     check(result, "Error binding ingredient search text: ");
     result = sqlite3_step(m_recipe_ingredient);
     check(result, "Error adding ingredient to recipe: ");
@@ -393,6 +454,17 @@ int Database::num_recipes(void) {
   return count;
 }
 
+int Database::count_recipes(const char *category) {
+  int result = sqlite3_bind_text(m_count_recipes_in_category, 1, category, -1, SQLITE_STATIC);
+  check(result, "Error binding category string: ");
+  result = sqlite3_step(m_count_recipes_in_category);
+  check(result, "Error counting recipes in category: ");
+  int count = sqlite3_column_int(m_count_recipes_in_category, 0);
+  result = sqlite3_reset(m_count_recipes_in_category);
+  check(result, "Error resetting statement for counting recipes in category: ");
+  return count;
+}
+
 vector<pair<sqlite3_int64, string> > Database::recipe_info(void) {
   int result;
   vector<pair<sqlite3_int64, string> > infos;
@@ -424,6 +496,22 @@ vector<string> Database::categories(void) {
   return categories;
 }
 
+vector<pair<string, int> > Database::categories_and_counts(void) {
+  int result;
+  vector<pair<string, int> > categories_and_counts;
+  while (true) {
+    result = sqlite3_step(m_category_and_count_list);
+    check(result, "Error getting categories and counts: ");
+    if (result != SQLITE_ROW)
+      break;
+    categories_and_counts.push_back(make_pair((const char *)sqlite3_column_text(m_category_and_count_list, 0),
+                                              sqlite3_column_int(m_category_and_count_list, 1)));
+  };
+  result = sqlite3_reset(m_category_and_count_list);
+  check(result, "Error resetting statement for getting categories and counts: ");
+  return categories_and_counts;
+}
+
 void Database::select_all(void) {
   int result;
   result = sqlite3_exec(m_db, "DROP TABLE IF EXISTS selection;", NULL, NULL, NULL);
@@ -638,15 +726,10 @@ void Database::delete_recipes(const vector<sqlite3_int64> &ids) {
 
 void Database::add_recipes_to_category(const vector<sqlite3_int64> &ids, const char *category) {
   // Create category.
-  int result = sqlite3_bind_text(m_add_category, 1, category, -1, SQLITE_STATIC);
-  check(result, "Error binding category name: ");
-  result = sqlite3_step(m_add_category);
-  check(result, "Error adding category: ");
-  result = sqlite3_reset(m_add_category);
-  check(result, "Error resetting category adding statement: ");
+  add_category(category);
   // Add recipes to category.
   for (vector<sqlite3_int64>::const_iterator id=ids.begin(); id!=ids.end(); id++) {
-    result = sqlite3_bind_int64(m_recipe_category, 1, *id);
+    int result = sqlite3_bind_int64(m_recipe_category, 1, *id);
     check(result, "Error binding recipe id: ");
     result = sqlite3_bind_text(m_recipe_category, 2, category, -1, SQLITE_STATIC);
     check(result, "Error binding category name: ");
@@ -670,6 +753,61 @@ void Database::remove_recipes_from_category(const vector<sqlite3_int64> &ids, co
   };
 }
 
+void Database::rename_category(const char *current_name, const char *new_name) {
+  int result = sqlite3_bind_text(m_rename_category, 1, current_name, -1, SQLITE_STATIC);
+  check(result, "Error binding old category name: ");
+  result = sqlite3_bind_text(m_rename_category, 2, new_name, -1, SQLITE_STATIC);
+  check(result, "Error binding new category name: ");
+  result = sqlite3_step(m_rename_category);
+  check(result, "Error renaming recipe category: ");
+  result = sqlite3_reset(m_rename_category);
+  check(result, "Error resetting rename category statement: ");
+}
+
+sqlite3_int64 Database::get_category_id(const char *name)
+{
+  sqlite3_int64 category_id = 0;
+  int result = sqlite3_bind_text(m_get_category_id, 1, name, -1, SQLITE_STATIC);
+  check(result, "Error binding old category name: ");
+  result = sqlite3_step(m_get_category_id);
+  check(result, "Error getting category id: ");
+  if (result == SQLITE_ROW)
+    category_id = sqlite3_column_int64(m_get_category_id, 0);
+  result = sqlite3_reset(m_get_category_id);
+  check(result, "Error resetting statement for getting category id: ");
+  return category_id;
+}
+
+void Database::merge_category(const char *category, const char *target) {
+  sqlite3_int64 category_id = get_category_id(category);
+  sqlite3_int64 target_id = get_category_id(target);
+  int result = sqlite3_bind_int64(m_merge_category, 1, category_id);
+  check(result, "Error binding category id for merging: ");
+  result = sqlite3_bind_int64(m_merge_category, 2, target_id);
+  check(result, "Error binding target category id for merging: ");
+  result = sqlite3_step(m_merge_category);
+  check(result, "Error merging category: ");
+  result = sqlite3_reset(m_merge_category);
+  check(result, "Error resetting statement for merging category: ");
+  delete_category(category);
+}
+
+void Database::delete_category(const char *category) {
+  sqlite3_int64 category_id = get_category_id(category);
+  int result = sqlite3_bind_int64(m_delete_recipe_category, 1, category_id);
+  check(result, "Error binding category id for deleting from recipe: ");
+  result = sqlite3_step(m_delete_recipe_category);
+  check(result, "Error deleting recipe category: ");
+  result = sqlite3_reset(m_delete_recipe_category);
+  check(result, "Error resetting statement for deleting recipe category: ");
+  result = sqlite3_bind_int64(m_delete_category, 1, category_id);
+  check(result, "Error binding category id for deleting: ");
+  result = sqlite3_step(m_delete_category);
+  check(result, "Error deleting category: ");
+  result = sqlite3_reset(m_delete_category);
+  check(result, "Error resetting statement for deleting category: ");
+}
+
 void Database::garbage_collect(void) {
   int result;
   // Clean up categories.
@@ -683,3 +821,31 @@ void Database::garbage_collect(void) {
   result = sqlite3_reset(m_clean_ingredients);
   check(result, "Error resetting statement for cleaning ingredients: ");
 }
+
+string Database::get_language(const char *default_language)
+{
+  string language;
+  int result = sqlite3_step(m_get_language);
+  check(result, "Error getting language: ");
+  if (result == SQLITE_ROW)
+    language = (const char *)sqlite3_column_text(m_get_language, 0);
+  else
+    language = default_language;
+  result = sqlite3_reset(m_get_language);
+  check(result, "Error resetting statement for getting language: ");
+  return language;
+}
+
+void Database::set_language(const char *language)
+{
+  int result = sqlite3_step(m_delete_language);
+  check(result, "Error deleting language: ");
+  result = sqlite3_reset(m_delete_language);
+  check(result, "Error resetting statement for deleting language: ");
+  result = sqlite3_bind_text(m_set_language, 1, language, -1, SQLITE_STATIC);
+  check(result, "Error binding language: ");
+  result = sqlite3_step(m_set_language);
+  check(result, "Error setting language: ");
+  result = sqlite3_reset(m_set_language);
+  check(result, "Error resetting statement for setting language: ");
+}
