@@ -1,5 +1,5 @@
 /* AnyMeal recipe management software
-   Copyright (C) 2020, 2023 Jan Wedekind
+   Copyright (C) 2020, 2024 Jan Wedekind
 
    This program is free software: you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
@@ -15,18 +15,21 @@
    along with this program.  If not, see <https://www.gnu.org/licenses/>. */
 #include <cassert>
 #include <sstream>
+#include <QtWidgets/QMessageBox>
 #include "html.hh"
 #include "edit_dialog.hh"
+#include "category_picker.hh"
 
 
 using namespace std;
 
 EditDialog::EditDialog(QWidget *parent):
-  QDialog(parent), m_converter_window(this), m_ingredient_model(NULL), m_instructions_model(NULL), m_title_validator(NULL)
+  QDialog(parent), m_converter_window(this), m_category_table_model(NULL), m_ingredient_model(NULL), m_instructions_model(NULL),
+  m_title_validator(NULL)
 {
   m_ui.setupUi(this);
   connect(m_ui.title_edit, &QLineEdit::textChanged, this, &EditDialog::update_ok_button);
-  connect(m_ui.categories_edit, &QLineEdit::textChanged, this, &EditDialog::update_ok_button);
+  connect(m_ui.categories_button, &QPushButton::clicked, this, &EditDialog::select_categories);
   connect(m_ui.servings_unit_edit, &QLineEdit::textChanged, this, &EditDialog::update_ok_button);
   connect(m_ui.amount_type_combo, SIGNAL(currentIndexChanged(int)), this, SLOT(amount_type_changed(int)));
   connect(m_ui.integer_spin, SIGNAL(valueChanged(int)), this, SLOT(amount_int_changed(int)));
@@ -48,24 +51,45 @@ EditDialog::EditDialog(QWidget *parent):
   connect(m_ui.instructions_edit, &QPlainTextEdit::textChanged, this, &EditDialog::instructions_text_changed);
   m_title_validator = new QRegExpValidator(QRegExp("\\S.*"), this);
   m_ui.title_edit->setValidator(m_title_validator);
-  m_categories_validator = new QRegExpValidator(QRegExp("\\S.*"), this);
-  m_ui.categories_edit->setValidator(m_categories_validator);
   m_servings_unit_validator = new QRegExpValidator(QRegExp("\\S.*"), this);
   m_ui.servings_unit_edit->setValidator(m_servings_unit_validator);
 }
 
+string EditDialog::category_string(const set<string> &categories) {
+  ostringstream result;
+  set<string>::const_iterator i = categories.begin();
+  while (i!=categories.end()) {
+    result << *i++;
+    if (i != categories.end())
+      result << ", ";
+    else
+      break;
+  };
+  return result.str();
+}
+
+set<string> EditDialog::categories(void) {
+  set<string> result;
+  string button_text = m_ui.categories_button->text().toUtf8().constData();
+  size_t pos;
+  while ((pos = button_text.find(',')) != string::npos) {
+    result.insert(button_text.substr(0, pos));
+    pos++;
+    while (pos < button_text.length() && button_text[pos] == ' ')
+      pos++;
+    button_text = button_text.substr(pos, button_text.length() - pos);
+  };
+  if (!button_text.empty())
+    result.insert(button_text);
+  return result;
+}
+
 void EditDialog::set_recipe(Recipe &recipe) {
   // Set title fields.
-  m_ui.title_edit->setText(recipe.title().c_str());
-  ostringstream categories;
-  for (unsigned int i=0; i<recipe.categories().size(); i++) {
-    categories << recipe.categories()[i];
-    if (i < recipe.categories().size() - 1)
-      categories << ", ";
-  };
-  m_ui.categories_edit->setText(categories.str().c_str());
+  m_ui.title_edit->setText(recipe.title_c_str());
+  m_ui.categories_button->setText(category_string(recipe.categories()).c_str());
   m_ui.servings_spin->setValue(recipe.servings());
-  m_ui.servings_unit_edit->setText(recipe.servings_unit().c_str());
+  m_ui.servings_unit_edit->setText(recipe.servings_unit_c_str());
   // Create ingredient model.
   if (m_ingredient_model) {
     m_ui.ingredients_view->setModel(NULL);
@@ -85,22 +109,17 @@ void EditDialog::set_recipe(Recipe &recipe) {
   m_instructions_model = new InstructionsModel(this, recipe.instructions(), recipe.instruction_sections());
   m_ui.instructions_view->setModel(m_instructions_model);
   connect(m_ui.instructions_view->selectionModel(), &QItemSelectionModel::currentChanged, this, &EditDialog::select_instruction);
+  update_ok_button();
 }
 
 Recipe EditDialog::get_recipe(void) {
   Recipe result;
   // Get title fields.
   result.set_title(m_ui.title_edit->text().toUtf8().constData());
-  string categories = m_ui.categories_edit->text().toUtf8().constData();
-  size_t pos;
-  while ((pos = categories.find(',')) != string::npos) {
-    result.add_category(categories.substr(0, pos).c_str());
-    pos++;
-    while (pos < categories.length() && categories[pos] == ' ')
-      pos++;
-    categories = categories.substr(pos, categories.length() - pos);
+  set<string> categories_ = categories();
+  for (set<string>::iterator i=categories_.begin(); i!=categories_.end(); i++) {
+    result.add_category((*i).c_str());
   };
-  result.add_category(categories.c_str());
   result.set_servings(m_ui.servings_spin->value());
   result.set_servings_unit(m_ui.servings_unit_edit->text().toUtf8().constData());
   // Get ingredients.
@@ -114,6 +133,21 @@ Recipe EditDialog::get_recipe(void) {
   return result;
 }
 
+void EditDialog::select_categories(void)
+{
+  try {
+    CategoryPicker category_picker;
+    m_category_table_model->reset(categories());
+    category_picker.set_model(m_category_table_model);
+    if (category_picker.exec() == QDialog::Accepted) {
+      m_ui.categories_button->setText(category_string(m_category_table_model->selection()).c_str());
+    };
+    update_ok_button();
+  } catch (exception &e) {
+    QMessageBox::critical(this, tr("Error While Selecting Categories"), e.what());
+  };
+}
+
 void EditDialog::select_ingredient(const QModelIndex &current, const QModelIndex &) {
   if (!current.isValid()) {
     m_ui.ingredient_stack->setCurrentIndex(2);
@@ -130,7 +164,7 @@ void EditDialog::select_ingredient(const QModelIndex &current, const QModelIndex
       m_ui.denominator_spin->setValue(ingredient.amount_denominator());
     };
     m_ui.unit_combo->setCurrentIndex(index_of_unit(ingredient.unit()));
-    m_ui.name_edit->setText(ingredient.text().c_str());
+    m_ui.name_edit->setText(ingredient.text_c_str());
   } else {
     m_ui.ingredient_stack->setCurrentIndex(1);
     m_ui.ingredient_section_edit->setText(m_ingredient_model->get_ingredient_section(current).c_str());
@@ -303,10 +337,23 @@ void EditDialog::update_ok_button(void) {
     return;
   if (!m_instructions_model)
     return;
-  bool enable = m_ui.title_edit->hasAcceptableInput() &&
-                m_ui.categories_edit->hasAcceptableInput() &&
-                m_ui.servings_unit_edit->hasAcceptableInput() &&
-                m_ingredient_model->has_acceptable_input() &&
-                m_instructions_model->has_acceptable_input();
+  bool enable = true;
+  m_ui.error_label->setText("");
+  if (!m_ui.title_edit->hasAcceptableInput()) {
+    m_ui.error_label->setText(tr("Title must not be empty."));
+    enable = false;
+  } else if (!m_ui.servings_unit_edit->hasAcceptableInput()) {
+    m_ui.error_label->setText(tr("Please enter servings unit."));
+    enable = false;
+  } else if (m_ui.categories_button->text().isEmpty()) {
+    m_ui.error_label->setText(tr("Need at least one category."));
+    enable = false;
+  } else if (!m_ingredient_model->has_acceptable_input()) {
+    m_ui.error_label->setText(tr("Ingredient name must not be empty."));
+    enable = false;
+  } else if (!m_instructions_model->has_acceptable_input()) {
+    m_ui.error_label->setText(tr("Instruction section title must not be empty."));
+    enable = false;
+  }
   m_ui.ok_button->setEnabled(enable);
 }
