@@ -1,6 +1,19 @@
 <?xml version="1.0" encoding="utf-8"?>
 <!DOCTYPE TS>
 <TS version="2.1" language="fr_FR">
+<context>
+    <name>AddDialog</name>
+    <message>
+        <location filename="../../add_dialog.ui" line="14"/>
+        <source>Add Category</source>
+        <translation>Ajouter une Catégorie</translation>
+    </message>
+    <message>
+        <location filename="../../add_dialog.ui" line="22"/>
+        <source>&amp;Add Category</source>
+        <translation>&amp;Ajouter une Catégorie</translation>
+    </message>
+</context>
 <context>
     <name>CategoryDialog</name>
     <message>
@@ -14,6 +27,67 @@
         <translation>&amp;Catégorie</translation>
     </message>
 </context>
+<context>
+    <name>CategoryPicker</name>
+    <message>
+        <location filename="../../category_picker.ui" line="14"/>
+        <source>Category Picker</source>
+        <translation>Sélection de catégorie</translation>
+    </message>
+    <message>
+        <location filename="../../category_picker.ui" line="37"/>
+        <source>&amp;Add</source>
+        <translation>&amp;Ajouter</translation>
+    </message>
+    <message>
+        <location filename="../../category_picker.ui" line="44"/>
+        <source>&amp;Delete</source>
+        <translation>Supprimer</translation>
+    </message>
+    <message>
+        <location filename="../../category_picker.ui" line="51"/>
+        <source>&amp;Rename</source>
+        <translation>&amp;Renommer</translation>
+    </message>
+    <message>
+        <location filename="../../category_picker.ui" line="58"/>
+        <source>&amp;Merge</source>
+        <translation>&amp;Fusionner</translation>
+    </message>
+    <message>
+        <location filename="../../category_picker.cc" line="52"/>
+        <source>Delete Categories</source>
+        <translation>Supprimer des catégories</translation>
+    </message>
+    <message>
+        <location filename="../../category_picker.cc" line="52"/>
+        <source>Do you want to delete the selected categories?</source>
+        <translation>Voulez-vous supprimer les catégories sélectionnées&#xa0;?</translation>
+    </message>
+    <message>
+        <location filename="../../category_picker.cc" line="87"/>
+        <source>Merge Category</source>
+        <translation>Fusionner la Catégorie</translation>
+    </message>
+    <message>
+        <location filename="../../category_picker.cc" line="87"/>
+        <source>Do you want to merge the category?</source>
+        <translation>Voulez-vous fusionner la catégorie&#xa0;?</translation>
+    </message>
+</context>
+<context>
+    <name>CategoryTableModel</name>
+    <message>
+        <location filename="../../category_table_model.cc" line="46"/>
+        <source>Category</source>
+        <translation>Catégorie</translation>
+    </message>
+    <message>
+        <location filename="../../category_table_model.cc" line="48"/>
+        <source># Recipes</source>
+        <translation># Recettes</translation>
+    </message>
+</context>
 <context>
     <name>ConverterWindow</name>
     <message>
@@ -175,38 +249,42 @@
         <translation>&amp;Général</translation>
     </message>
     <message>
-        <location filename="../../edit_dialog.ui" line="36"/>
+        <location filename="../../edit_dialog.ui" line="46"/>
         <location filename="../../edit_dialog.ui" line="570"/>
         <source>&amp;Title:</source>
         <translation>&amp;Titre</translation>
     </message>
     <message>
-        <location filename="../../edit_dialog.ui" line="49"/>
+        <location filename="../../edit_dialog.ui" line="93"/>
         <location filename="../../edit_dialog.ui" line="717"/>
         <source>title</source>
         <translation>titre
 </translation>
     </message>
     <message>
-        <location filename="../../edit_dialog.ui" line="56"/>
+        <location filename="../../edit_dialog.ui" line="36"/>
         <source>&amp;Categories:</source>
         <translation>&amp;Catégories</translation>
     </message>
     <message>
-        <location filename="../../edit_dialog.ui" line="66"/>
         <source>category1, category2, ...</source>
-        <translation>catégorie 1, catégorie 2 ...</translation>
+        <translation type="vanished">catégorie 1, catégorie 2 ...</translation>
     </message>
     <message>
-        <location filename="../../edit_dialog.ui" line="73"/>
+        <location filename="../../edit_dialog.ui" line="56"/>
         <source>&amp;Yield:</source>
         <translation>&amp;Couverts</translation>
     </message>
     <message>
-        <location filename="../../edit_dialog.ui" line="98"/>
+        <location filename="../../edit_dialog.ui" line="81"/>
         <source>servings</source>
         <translation>couverts</translation>
     </message>
+    <message>
+        <location filename="../../edit_dialog.ui" line="100"/>
+        <source>None</source>
+        <translation>Aucun</translation>
+    </message>
     <message>
         <location filename="../../edit_dialog.ui" line="123"/>
         <source>&amp;Ingredients</source>
@@ -447,7 +525,7 @@
     </message>
     <message>
         <location filename="../../edit_dialog.ui" line="548"/>
-        <location filename="../../edit_dialog.cc" line="220"/>
+        <location filename="../../edit_dialog.cc" line="254"/>
         <source>ingredient</source>
         <translation>ingrédient</translation>
     </message>
@@ -482,20 +560,50 @@
         <translation>&amp;Titre</translation>
     </message>
     <message>
-        <location filename="../../edit_dialog.ui" line="755"/>
+        <location filename="../../edit_dialog.ui" line="761"/>
         <source>&amp;Ok</source>
         <translation>&amp;OK</translation>
     </message>
     <message>
-        <location filename="../../edit_dialog.ui" line="765"/>
+        <location filename="../../edit_dialog.ui" line="771"/>
         <source>&amp;Cancel</source>
         <translation>&amp;Annuler</translation>
     </message>
     <message>
-        <location filename="../../edit_dialog.cc" line="242"/>
+        <location filename="../../edit_dialog.cc" line="147"/>
+        <source>Error While Selecting Categories</source>
+        <translation>Erreur lors de la sélection des catégories</translation>
+    </message>
+    <message>
+        <location filename="../../edit_dialog.cc" line="276"/>
         <source>Title</source>
         <translation>Titre</translation>
     </message>
+    <message>
+        <location filename="../../edit_dialog.cc" line="343"/>
+        <source>Title must not be empty.</source>
+        <translation>Le titre ne doit pas être vide.</translation>
+    </message>
+    <message>
+        <location filename="../../edit_dialog.cc" line="346"/>
+        <source>Please enter servings unit.</source>
+        <translation>Veuillez saisir l&apos;unité de portion.</translation>
+    </message>
+    <message>
+        <location filename="../../edit_dialog.cc" line="349"/>
+        <source>Need at least one category.</source>
+        <translation>Il faut au moins une catégorie.</translation>
+    </message>
+    <message>
+        <location filename="../../edit_dialog.cc" line="352"/>
+        <source>Ingredient name must not be empty.</source>
+        <translation>Le nom de l&apos;ingrédient ne doit pas être vide.</translation>
+    </message>
+    <message>
+        <location filename="../../edit_dialog.cc" line="355"/>
+        <source>Instruction section title must not be empty.</source>
+        <translation>Le titre de la section d&apos;instructions ne doit pas être vide.</translation>
+    </message>
 </context>
 <context>
     <name>ExportDialog</name>
@@ -755,406 +863,538 @@
         <translation>&amp;Rechercher</translation>
     </message>
     <message>
-        <location filename="../../main_window.ui" line="201"/>
+        <location filename="../../main_window.ui" line="211"/>
         <source>&amp;File</source>
         <translation>&amp;Fichier</translation>
     </message>
     <message>
-        <location filename="../../main_window.ui" line="214"/>
+        <location filename="../../main_window.ui" line="224"/>
         <source>&amp;Help</source>
         <translation>&amp;Aide</translation>
     </message>
     <message>
-        <location filename="../../main_window.ui" line="221"/>
+        <location filename="../../main_window.ui" line="231"/>
         <source>Edit</source>
         <translation>Edition</translation>
     </message>
     <message>
-        <location filename="../../main_window.ui" line="236"/>
+        <location filename="../../main_window.ui" line="241"/>
+        <source>Language</source>
+        <translation>Langue</translation>
+    </message>
+    <message>
+        <location filename="../../main_window.ui" line="258"/>
         <source>Tool Bar</source>
         <translation>Barre d&apos;outils</translation>
     </message>
     <message>
-        <location filename="../../main_window.ui" line="264"/>
+        <location filename="../../main_window.ui" line="286"/>
         <source>&amp;Quit</source>
         <translation>&amp;Quitter</translation>
     </message>
     <message>
-        <location filename="../../main_window.ui" line="267"/>
+        <location filename="../../main_window.ui" line="289"/>
+        <location filename="../../main_window.ui" line="292"/>
         <source>Exit application</source>
         <translation>Quitter l&apos;application</translation>
     </message>
     <message>
-        <location filename="../../main_window.ui" line="270"/>
+        <location filename="../../main_window.ui" line="295"/>
         <source>Ctrl+Q</source>
         <translation></translation>
     </message>
     <message>
-        <location filename="../../main_window.ui" line="279"/>
+        <location filename="../../main_window.ui" line="304"/>
         <source>&amp;Import recipes</source>
         <translation>&amp;Importer des recettes</translation>
     </message>
     <message>
-        <location filename="../../main_window.ui" line="282"/>
+        <location filename="../../main_window.ui" line="307"/>
+        <location filename="../../main_window.ui" line="310"/>
         <source>Read MealMaster recipes from files</source>
         <translation>Ouvrir des recettes MealMaster</translation>
     </message>
     <message>
-        <location filename="../../main_window.ui" line="285"/>
+        <location filename="../../main_window.ui" line="313"/>
         <source>Ctrl+I</source>
         <translation>Ctrl+I</translation>
     </message>
     <message>
-        <location filename="../../main_window.ui" line="294"/>
+        <location filename="../../main_window.ui" line="322"/>
         <source>Print p&amp;review</source>
         <translation>Aperçu avant i&amp;mpression</translation>
     </message>
     <message>
-        <location filename="../../main_window.ui" line="297"/>
+        <location filename="../../main_window.ui" line="325"/>
+        <location filename="../../main_window.ui" line="328"/>
         <source>Print preview of current recipe</source>
         <translation>Aperçu de la recette courante avant impression</translation>
     </message>
     <message>
-        <location filename="../../main_window.ui" line="300"/>
+        <location filename="../../main_window.ui" line="331"/>
         <source>Ctrl+R</source>
         <translation>Ctrl+R</translation>
     </message>
     <message>
-        <location filename="../../main_window.ui" line="309"/>
+        <location filename="../../main_window.ui" line="340"/>
         <source>&amp;Print recipe</source>
         <translation>&amp;Imprimer la recette</translation>
     </message>
     <message>
-        <location filename="../../main_window.ui" line="312"/>
+        <location filename="../../main_window.ui" line="343"/>
+        <location filename="../../main_window.ui" line="346"/>
         <source>Print current recipe</source>
         <translation>Imprimer la recette courante</translation>
     </message>
     <message>
-        <location filename="../../main_window.ui" line="315"/>
+        <location filename="../../main_window.ui" line="349"/>
         <source>Ctrl+P</source>
         <translation>Ctrl+P</translation>
     </message>
     <message>
-        <location filename="../../main_window.ui" line="324"/>
+        <location filename="../../main_window.ui" line="358"/>
         <source>A&amp;bout AnyMeal</source>
         <translation>A &amp;propos d&apos;Anymeal</translation>
     </message>
     <message>
-        <location filename="../../main_window.ui" line="327"/>
+        <location filename="../../main_window.ui" line="361"/>
+        <source>About AnyMeal</source>
+        <translation>A propos d&apos;Anymeal</translation>
+    </message>
+    <message>
+        <location filename="../../main_window.ui" line="364"/>
         <source>Ctrl+B</source>
         <translation>Ctrl+B</translation>
     </message>
     <message>
-        <location filename="../../main_window.ui" line="336"/>
+        <location filename="../../main_window.ui" line="373"/>
         <source>&amp;Delete recipes</source>
         <translation>&amp;Supprimer les recettes</translation>
     </message>
     <message>
-        <location filename="../../main_window.ui" line="339"/>
+        <location filename="../../main_window.ui" line="376"/>
+        <location filename="../../main_window.ui" line="379"/>
         <source>Delete selected recipes</source>
         <translation>Supprimer les recettes sélectionnées</translation>
     </message>
     <message>
-        <location filename="../../main_window.ui" line="342"/>
+        <location filename="../../main_window.ui" line="382"/>
         <source>Del</source>
         <translation>Supp.</translation>
     </message>
     <message>
-        <location filename="../../main_window.ui" line="351"/>
+        <location filename="../../main_window.ui" line="391"/>
         <source>Exp&amp;ort recipes</source>
         <translation>Exp&amp;orter des recettes</translation>
     </message>
     <message>
-        <location filename="../../main_window.ui" line="354"/>
+        <location filename="../../main_window.ui" line="394"/>
+        <location filename="../../main_window.ui" line="397"/>
         <source>Write MealMaster recipes to file</source>
         <translation>Enregistrer des recettes MealMaster</translation>
     </message>
     <message>
-        <location filename="../../main_window.ui" line="357"/>
+        <location filename="../../main_window.ui" line="400"/>
         <source>Ctrl+O</source>
         <translation>Ctrl+O</translation>
     </message>
     <message>
-        <location filename="../../main_window.ui" line="366"/>
+        <location filename="../../main_window.ui" line="409"/>
         <source>&amp;Edit Recipe</source>
         <translation>&amp;Modifier la recette</translation>
     </message>
     <message>
-        <location filename="../../main_window.ui" line="369"/>
+        <location filename="../../main_window.ui" line="412"/>
+        <location filename="../../main_window.ui" line="415"/>
         <source>Edit current recipe</source>
         <translation>Modifier la recette courante</translation>
     </message>
     <message>
-        <location filename="../../main_window.ui" line="372"/>
+        <location filename="../../main_window.ui" line="418"/>
         <source>Ctrl+E</source>
         <translation>Ctrl+E</translation>
     </message>
     <message>
-        <location filename="../../main_window.ui" line="381"/>
+        <location filename="../../main_window.ui" line="427"/>
         <source>Collect &amp;Garbage</source>
         <translation>Ramasser les Ord&amp;ures</translation>
     </message>
     <message>
-        <location filename="../../main_window.ui" line="384"/>
+        <location filename="../../main_window.ui" line="430"/>
+        <location filename="../../main_window.ui" line="433"/>
         <source>Delete unused categories and ingredients</source>
         <translation>Supprimer les catégories et ingrédients inutilisés</translation>
     </message>
     <message>
-        <location filename="../../main_window.ui" line="387"/>
+        <location filename="../../main_window.ui" line="436"/>
         <source>Ctrl+G</source>
         <translation>Ctrl+U</translation>
     </message>
     <message>
-        <location filename="../../main_window.ui" line="396"/>
+        <location filename="../../main_window.ui" line="445"/>
         <source>Add &amp;to Category</source>
         <translation>Ajou&amp;ter à une catégorie</translation>
     </message>
     <message>
-        <location filename="../../main_window.ui" line="399"/>
+        <location filename="../../main_window.ui" line="448"/>
+        <location filename="../../main_window.ui" line="451"/>
         <source>Add selected recipes to a category</source>
         <translation>Ajouter à une ca&amp;tégorie les recettes sélectionnées</translation>
     </message>
     <message>
-        <location filename="../../main_window.ui" line="402"/>
+        <location filename="../../main_window.ui" line="454"/>
         <source>Ctrl+T</source>
         <translation>Ctrl+T</translation>
     </message>
     <message>
-        <location filename="../../main_window.ui" line="411"/>
+        <location filename="../../main_window.ui" line="463"/>
         <source>&amp;Remove from Category</source>
         <translation>&amp;Retirer d&apos;une catégorie</translation>
     </message>
     <message>
-        <location filename="../../main_window.ui" line="414"/>
+        <location filename="../../main_window.ui" line="466"/>
+        <source>Remove from Category</source>
+        <translation>Retirer d&apos;une catégorie</translation>
+    </message>
+    <message>
+        <location filename="../../main_window.ui" line="469"/>
         <source>Ctrl+D</source>
         <translation>Ctrl+R</translation>
     </message>
     <message>
-        <location filename="../../main_window.ui" line="423"/>
+        <location filename="../../main_window.ui" line="478"/>
         <source>Open Co&amp;nverter Window</source>
         <translation>Ouvrir le co&amp;nvertisseur</translation>
     </message>
     <message>
-        <location filename="../../main_window.ui" line="426"/>
+        <location filename="../../main_window.ui" line="481"/>
+        <source>Open Converter Window</source>
+        <translation>Ouvrir le convertisseur</translation>
+    </message>
+    <message>
+        <location filename="../../main_window.ui" line="484"/>
         <source>Ctrl+U</source>
         <translation>Ctrl+U</translation>
     </message>
     <message>
-        <location filename="../../main_window.ui" line="453"/>
+        <location filename="../../main_window.ui" line="517"/>
         <source>Ctrl+N</source>
         <translation>Ctrl+N</translation>
     </message>
     <message>
-        <location filename="../../main_window.ui" line="435"/>
+        <location filename="../../main_window.ui" line="526"/>
+        <source>English</source>
+        <translation>Anglaise</translation>
+    </message>
+    <message>
+        <location filename="../../main_window.ui" line="535"/>
+        <source>German</source>
+        <translation>Allemande</translation>
+    </message>
+    <message>
+        <location filename="../../main_window.ui" line="544"/>
+        <source>French</source>
+        <translation>Français</translation>
+    </message>
+    <message>
+        <location filename="../../main_window.ui" line="553"/>
+        <source>Italian</source>
+        <translation>Italienne</translation>
+    </message>
+    <message>
+        <location filename="../../main_window.ui" line="562"/>
+        <source>Slovenian</source>
+        <translation>Slovène</translation>
+    </message>
+    <message>
+        <location filename="../../main_window.ui" line="571"/>
+        <source>Dutch</source>
+        <translation>Néerlandaise</translation>
+    </message>
+    <message>
+        <location filename="../../main_window.ui" line="493"/>
         <source>Remove duplicates</source>
         <translation>Supprimer les doublons</translation>
     </message>
     <message>
-        <location filename="../../main_window.ui" line="438"/>
+        <location filename="../../main_window.ui" line="496"/>
+        <location filename="../../main_window.ui" line="499"/>
         <source>Remove duplicates in selected recipes</source>
         <translation>Supprimer les doublons dans les recettes sélectionnées</translation>
     </message>
     <message>
-        <location filename="../../main_window.ui" line="447"/>
+        <location filename="../../main_window.ui" line="508"/>
         <source>New</source>
         <translation>Nouveau</translation>
     </message>
     <message>
-        <location filename="../../main_window.ui" line="450"/>
+        <location filename="../../main_window.ui" line="511"/>
+        <location filename="../../main_window.ui" line="514"/>
         <source>New recipe</source>
         <translation>Nouvelle recette</translation>
     </message>
     <message>
-        <location filename="../../main_window.cc" line="92"/>
+        <location filename="../../main_window.cc" line="105"/>
         <source>Error Opening Database</source>
         <translation>Erreur d&apos;ouverture de la base de données</translation>
     </message>
     <message>
-        <location filename="../../main_window.cc" line="98"/>
+        <location filename="../../main_window.cc" line="184"/>
         <source>Showing %1 recipes ...</source>
         <translation>Affiche %1 recettes ...</translation>
     </message>
     <message>
-        <location filename="../../main_window.cc" line="108"/>
+        <location filename="../../main_window.cc" line="194"/>
         <source>Import MealMaster Files</source>
         <translation>Importer des fichiers MealMaster</translation>
     </message>
     <message>
-        <location filename="../../main_window.cc" line="108"/>
-        <location filename="../../main_window.cc" line="438"/>
+        <location filename="../../main_window.cc" line="194"/>
+        <location filename="../../main_window.cc" line="568"/>
         <source>MealMaster (*.mm *.MM *.mmf *.MMF);;Text (*.txt *.TXT);;All files (*)</source>
         <translation>MealMaster (*.mm *.MM *.mmf *.MMF);;Texte (*.txt *.TXT);;Tous les fichiers (*)</translation>
     </message>
     <message>
-        <location filename="../../main_window.cc" line="114"/>
+        <location filename="../../main_window.cc" line="200"/>
         <source>Importing files ...</source>
         <translation>Importation en cours</translation>
     </message>
     <message>
-        <location filename="../../main_window.cc" line="114"/>
-        <location filename="../../main_window.cc" line="445"/>
-        <location filename="../../main_window.cc" line="546"/>
+        <location filename="../../main_window.cc" line="200"/>
+        <location filename="../../main_window.cc" line="575"/>
+        <location filename="../../main_window.cc" line="676"/>
         <source>Cancel</source>
         <translation>Annuler</translation>
     </message>
     <message>
-        <location filename="../../main_window.cc" line="123"/>
+        <location filename="../../main_window.cc" line="210"/>
         <source>%1 imported and %2 failed ...</source>
         <translation>%1 importées et %2 échouées</translation>
     </message>
     <message>
-        <location filename="../../main_window.cc" line="137"/>
+        <location filename="../../main_window.cc" line="224"/>
         <source>Rejected recipe: </source>
         <translation>Recette rejetée:</translation>
     </message>
     <message>
-        <location filename="../../main_window.cc" line="142"/>
-        <location filename="../../main_window.cc" line="469"/>
-        <location filename="../../main_window.cc" line="477"/>
+        <location filename="../../main_window.cc" line="229"/>
+        <location filename="../../main_window.cc" line="248"/>
+        <location filename="../../main_window.cc" line="599"/>
+        <location filename="../../main_window.cc" line="607"/>
         <source>Error writing to file </source>
         <translation>Erreur d&apos;écriture</translation>
     </message>
     <message>
-        <location filename="../../main_window.cc" line="163"/>
+        <location filename="../../main_window.cc" line="259"/>
         <source>Recipes Imported</source>
         <translation>Recettes importées</translation>
     </message>
     <message>
-        <location filename="../../main_window.cc" line="163"/>
+        <location filename="../../main_window.cc" line="259"/>
         <source>%1 imported and %2 failed.</source>
         <translation>%1 importées et %2 échouées</translation>
     </message>
     <message>
-        <location filename="../../main_window.cc" line="167"/>
+        <location filename="../../main_window.cc" line="263"/>
         <source>Error While Importing</source>
         <translation>Erreur lors de l&apos;import</translation>
     </message>
     <message>
-        <location filename="../../main_window.cc" line="178"/>
+        <location filename="../../main_window.cc" line="274"/>
         <source>Edit current recipe, a copy of the recipe, a new recipe, or cancel?</source>
         <translation>Modifier la recette courante, créer une copie, une nouvelle recette ou annuler?</translation>
     </message>
     <message>
-        <location filename="../../main_window.cc" line="179"/>
+        <location filename="../../main_window.cc" line="275"/>
         <source>&amp;Edit Current</source>
         <translation>Modifier la r&amp;ecette courante</translation>
     </message>
     <message>
-        <location filename="../../main_window.cc" line="180"/>
+        <location filename="../../main_window.cc" line="276"/>
         <source>Edit C&amp;opy</source>
         <translation>Créer une c&amp;opie</translation>
     </message>
     <message>
-        <location filename="../../main_window.cc" line="181"/>
+        <location filename="../../main_window.cc" line="277"/>
         <source>Edit &amp;New</source>
         <translation>Créer une &amp;nouvelle recette</translation>
     </message>
     <message>
-        <location filename="../../main_window.cc" line="182"/>
+        <location filename="../../main_window.cc" line="278"/>
         <source>&amp;Cancel</source>
         <translation>&amp;Annuler</translation>
     </message>
     <message>
-        <location filename="../../main_window.cc" line="250"/>
+        <location filename="../../main_window.cc" line="306"/>
+        <source>Title</source>
+        <translation>Titre</translation>
+    </message>
+    <message>
+        <location filename="../../main_window.cc" line="470"/>
+        <source>title</source>
+        <translation>titre</translation>
+    </message>
+    <message>
+        <source>Category</source>
+        <translation type="vanished">Catégorie</translation>
+    </message>
+    <message>
+        <location filename="../../main_window.cc" line="244"/>
+        <source>Unexpected end of file in %1</source>
+        <translation>Fin de fichier inattendue dans %1</translation>
+    </message>
+    <message>
+        <location filename="../../main_window.cc" line="308"/>
+        <source>Servings</source>
+        <translation>Couverts</translation>
+    </message>
+    <message>
+        <location filename="../../main_window.cc" line="357"/>
         <source>Error While Updating Recipe</source>
         <translation>Erreur lors de la mise à jour</translation>
     </message>
     <message>
-        <location filename="../../main_window.cc" line="275"/>
+        <location filename="../../main_window.cc" line="382"/>
         <source>Error Adding Recipes to Category</source>
         <translation>Erreur lors de l&apos;ajout de recettes à une catégorie</translation>
     </message>
     <message>
-        <location filename="../../main_window.cc" line="301"/>
+        <location filename="../../main_window.cc" line="408"/>
         <source>Error Removing Recipes from Category</source>
         <translation>Erreur lors du retrait de recettes d&apos;une catégorie</translation>
     </message>
     <message>
-        <location filename="../../main_window.cc" line="320"/>
+        <location filename="../../main_window.cc" line="427"/>
         <source>Error Collecting Garbage</source>
         <translation>Erreur lors de la collecte des déchets</translation>
     </message>
     <message>
-        <location filename="../../main_window.cc" line="329"/>
+        <location filename="../../main_window.cc" line="436"/>
         <source>About AnyMeal %1</source>
         <translation>A propos d&apos;Anymeal %1</translation>
     </message>
     <message>
-        <location filename="../../main_window.cc" line="374"/>
+        <location filename="../../main_window.cc" line="478"/>
+        <source>category</source>
+        <translation>catégorie</translation>
+    </message>
+    <message>
+        <location filename="../../main_window.cc" line="481"/>
+        <source>not category</source>
+        <translation>pas de catégorie</translation>
+    </message>
+    <message>
+        <location filename="../../main_window.cc" line="490"/>
+        <source>ingredient</source>
+        <translation>ingrédient</translation>
+    </message>
+    <message>
+        <location filename="../../main_window.cc" line="493"/>
+        <source>not ingredient</source>
+        <translation>pas d&apos;ingrédient</translation>
+    </message>
+    <message>
+        <location filename="../../main_window.cc" line="503"/>
         <source>Error Filtering Recipes</source>
         <translation>Erreur lors du filtrage des recettes</translation>
     </message>
     <message>
-        <location filename="../../main_window.cc" line="388"/>
+        <location filename="../../main_window.cc" line="518"/>
         <source>Error Resetting Selection</source>
         <translation>Erreur de réinitialisation de la sélection</translation>
     </message>
     <message>
-        <location filename="../../main_window.cc" line="408"/>
+        <location filename="../../main_window.cc" line="538"/>
         <source>Error fetching recipe</source>
         <translation>Erreur lors de la recherche</translation>
     </message>
     <message>
-        <location filename="../../main_window.cc" line="438"/>
+        <location filename="../../main_window.cc" line="568"/>
         <source>Export MealMaster File</source>
         <translation>Exporter un fichier MealMaster</translation>
     </message>
     <message>
-        <location filename="../../main_window.cc" line="445"/>
+        <location filename="../../main_window.cc" line="575"/>
         <source>Exporting recipes ...</source>
         <translation>Exportation en cours</translation>
     </message>
     <message>
-        <location filename="../../main_window.cc" line="464"/>
+        <location filename="../../main_window.cc" line="594"/>
         <source>Failed recipe: </source>
         <translation>Recette ratée:</translation>
     </message>
     <message>
-        <location filename="../../main_window.cc" line="480"/>
+        <location filename="../../main_window.cc" line="610"/>
         <source>%1 exported and %2 failed ...</source>
         <translation>%1 exportées et %2 échouées</translation>
     </message>
     <message>
-        <location filename="../../main_window.cc" line="483"/>
+        <location filename="../../main_window.cc" line="613"/>
         <source>Recipes Exported</source>
         <translation>Recettes exportées</translation>
     </message>
     <message>
-        <location filename="../../main_window.cc" line="483"/>
+        <location filename="../../main_window.cc" line="613"/>
         <source>%1 exported and %2 failed.</source>
         <translation>%1 exportées et %2 échouées</translation>
     </message>
     <message>
-        <location filename="../../main_window.cc" line="487"/>
+        <location filename="../../main_window.cc" line="617"/>
         <source>Error While Exporting</source>
         <translation>Erreur lors de l&apos;export</translation>
     </message>
     <message>
-        <location filename="../../main_window.cc" line="495"/>
+        <location filename="../../main_window.cc" line="625"/>
         <source>Delete Recipes</source>
         <translation>Supprimer les recettes</translation>
     </message>
     <message>
-        <location filename="../../main_window.cc" line="495"/>
+        <location filename="../../main_window.cc" line="625"/>
         <source>Do you want to delete the selected recipes?</source>
         <translation>Voulez-vous supprimer les recettes sélectionnées?</translation>
     </message>
     <message>
-        <location filename="../../main_window.cc" line="514"/>
+        <location filename="../../main_window.cc" line="644"/>
         <source>Error Deleting Recipes</source>
         <translation>Erreur lors de la suppression</translation>
     </message>
     <message>
-        <location filename="../../main_window.cc" line="546"/>
+        <location filename="../../main_window.cc" line="676"/>
         <source>Detecting duplicates ...</source>
         <translation>Détection des doublons...</translation>
     </message>
     <message>
-        <location filename="../../main_window.cc" line="549"/>
+        <location filename="../../main_window.cc" line="679"/>
         <source>Found %1 duplicates ...</source>
         <translation>J&apos;ai trouvé %1 doublons...</translation>
     </message>
 </context>
+<context>
+    <name>MergeDialog</name>
+    <message>
+        <location filename="../../merge_dialog.ui" line="14"/>
+        <source>Merge Category</source>
+        <translation>Fusionner la Catégorie</translation>
+    </message>
+    <message>
+        <location filename="../../merge_dialog.ui" line="22"/>
+        <source>Merge Category Into:</source>
+        <translation>Fusionner la catégorie dans:</translation>
+    </message>
+</context>
+<context>
+    <name>RenameDialog</name>
+    <message>
+        <location filename="../../rename_dialog.ui" line="14"/>
+        <source>Rename Category</source>
+        <translation>Renommer la Catégorie</translation>
+    </message>
+    <message>
+        <location filename="../../rename_dialog.ui" line="22"/>
+        <source>Rename Category To:</source>
+        <translation>Renommer la catégorie en:</translation>
+    </message>
+</context>
 <context>
     <name>recipe</name>
     <message>
@@ -1163,34 +1403,34 @@
         <translation>Catégories</translation>
     </message>
     <message>
-        <location filename="../../html.cc" line="192"/>
+        <location filename="../../html.cc" line="195"/>
         <source>Yield</source>
         <translation>Couverts</translation>
     </message>
     <message>
-        <location filename="../../html.cc" line="196"/>
+        <location filename="../../html.cc" line="199"/>
         <source>Ingredients</source>
         <translation>Ingrédients</translation>
     </message>
     <message>
-        <location filename="../../html.cc" line="199"/>
+        <location filename="../../html.cc" line="202"/>
         <source>amount</source>
         <translation>quantité</translation>
     </message>
     <message>
-        <location filename="../../html.cc" line="200"/>
+        <location filename="../../html.cc" line="203"/>
         <source>unit</source>
         <translation>unité</translation>
     </message>
     <message>
-        <location filename="../../html.cc" line="201"/>
+        <location filename="../../html.cc" line="204"/>
         <source>ingredient</source>
         <translation>ingrédient</translation>
     </message>
     <message>
-        <location filename="../../html.cc" line="221"/>
+        <location filename="../../html.cc" line="224"/>
         <source>Instructions</source>
-        <translation>instructions</translation>
+        <translation>Instructions</translation>
     </message>
 </context>
 <context>
