@@ -1,6 +1,19 @@
 <?xml version="1.0" encoding="utf-8"?>
 <!DOCTYPE TS>
 <TS version="2.1" language="it_IT">
+<context>
+    <name>AddDialog</name>
+    <message>
+        <location filename="../../add_dialog.ui" line="14"/>
+        <source>Add Category</source>
+        <translation>Aggiungi Categoria</translation>
+    </message>
+    <message>
+        <location filename="../../add_dialog.ui" line="22"/>
+        <source>&amp;Add Category</source>
+        <translation>&amp;Aggiungi Categoria</translation>
+    </message>
+</context>
 <context>
     <name>CategoryDialog</name>
     <message>
@@ -14,6 +27,67 @@
         <translation>&amp;Categoria</translation>
     </message>
 </context>
+<context>
+    <name>CategoryPicker</name>
+    <message>
+        <location filename="../../category_picker.ui" line="14"/>
+        <source>Category Picker</source>
+        <translation>Selettore di categorie</translation>
+    </message>
+    <message>
+        <location filename="../../category_picker.ui" line="37"/>
+        <source>&amp;Add</source>
+        <translation>&amp;Aggiungere</translation>
+    </message>
+    <message>
+        <location filename="../../category_picker.ui" line="44"/>
+        <source>&amp;Delete</source>
+        <translation>&amp;Eliminare</translation>
+    </message>
+    <message>
+        <location filename="../../category_picker.ui" line="51"/>
+        <source>&amp;Rename</source>
+        <translation>&amp;Rinominare</translation>
+    </message>
+    <message>
+        <location filename="../../category_picker.ui" line="58"/>
+        <source>&amp;Merge</source>
+        <translation>&amp;Unisci</translation>
+    </message>
+    <message>
+        <location filename="../../category_picker.cc" line="52"/>
+        <source>Delete Categories</source>
+        <translation>Elimina categorie</translation>
+    </message>
+    <message>
+        <location filename="../../category_picker.cc" line="52"/>
+        <source>Do you want to delete the selected categories?</source>
+        <translation>Vuoi eliminare le categorie selezionate?</translation>
+    </message>
+    <message>
+        <location filename="../../category_picker.cc" line="87"/>
+        <source>Merge Category</source>
+        <translation>Unisci Categoria</translation>
+    </message>
+    <message>
+        <location filename="../../category_picker.cc" line="87"/>
+        <source>Do you want to merge the category?</source>
+        <translation>Vuoi unire la categoria?</translation>
+    </message>
+</context>
+<context>
+    <name>CategoryTableModel</name>
+    <message>
+        <location filename="../../category_table_model.cc" line="46"/>
+        <source>Category</source>
+        <translation>Categoria</translation>
+    </message>
+    <message>
+        <location filename="../../category_table_model.cc" line="48"/>
+        <source># Recipes</source>
+        <translation>#Ricette</translation>
+    </message>
+</context>
 <context>
     <name>ConverterWindow</name>
     <message>
@@ -175,37 +249,41 @@
         <translation>&amp;Generale</translation>
     </message>
     <message>
-        <location filename="../../edit_dialog.ui" line="36"/>
+        <location filename="../../edit_dialog.ui" line="46"/>
         <location filename="../../edit_dialog.ui" line="570"/>
         <source>&amp;Title:</source>
         <translation>&amp;Titolo:</translation>
     </message>
     <message>
-        <location filename="../../edit_dialog.ui" line="49"/>
+        <location filename="../../edit_dialog.ui" line="93"/>
         <location filename="../../edit_dialog.ui" line="717"/>
         <source>title</source>
         <translation>titolo</translation>
     </message>
     <message>
-        <location filename="../../edit_dialog.ui" line="56"/>
+        <location filename="../../edit_dialog.ui" line="36"/>
         <source>&amp;Categories:</source>
         <translation>&amp;Categorie:</translation>
     </message>
     <message>
-        <location filename="../../edit_dialog.ui" line="66"/>
         <source>category1, category2, ...</source>
-        <translation>categoria1, categoria2, ...</translation>
+        <translation type="vanished">categoria1, categoria2, ...</translation>
     </message>
     <message>
-        <location filename="../../edit_dialog.ui" line="73"/>
+        <location filename="../../edit_dialog.ui" line="56"/>
         <source>&amp;Yield:</source>
         <translation>&amp;Resa:</translation>
     </message>
     <message>
-        <location filename="../../edit_dialog.ui" line="98"/>
+        <location filename="../../edit_dialog.ui" line="81"/>
         <source>servings</source>
         <translation>porzioni</translation>
     </message>
+    <message>
+        <location filename="../../edit_dialog.ui" line="100"/>
+        <source>None</source>
+        <translation>Nessuno</translation>
+    </message>
     <message>
         <location filename="../../edit_dialog.ui" line="123"/>
         <source>&amp;Ingredients</source>
@@ -446,7 +524,7 @@
     </message>
     <message>
         <location filename="../../edit_dialog.ui" line="548"/>
-        <location filename="../../edit_dialog.cc" line="220"/>
+        <location filename="../../edit_dialog.cc" line="254"/>
         <source>ingredient</source>
         <translation>ingrediente</translation>
     </message>
@@ -481,20 +559,50 @@
         <translation>&amp;Titolo</translation>
     </message>
     <message>
-        <location filename="../../edit_dialog.ui" line="755"/>
+        <location filename="../../edit_dialog.ui" line="761"/>
         <source>&amp;Ok</source>
         <translation>&amp;Ok</translation>
     </message>
     <message>
-        <location filename="../../edit_dialog.ui" line="765"/>
+        <location filename="../../edit_dialog.ui" line="771"/>
         <source>&amp;Cancel</source>
         <translation>&amp;Annulla</translation>
     </message>
     <message>
-        <location filename="../../edit_dialog.cc" line="242"/>
+        <location filename="../../edit_dialog.cc" line="147"/>
+        <source>Error While Selecting Categories</source>
+        <translation>Errore durante la selezione della categorie</translation>
+    </message>
+    <message>
+        <location filename="../../edit_dialog.cc" line="276"/>
         <source>Title</source>
         <translation>Titolo</translation>
     </message>
+    <message>
+        <location filename="../../edit_dialog.cc" line="343"/>
+        <source>Title must not be empty.</source>
+        <translation>Il titolo non può essere vuoto.</translation>
+    </message>
+    <message>
+        <location filename="../../edit_dialog.cc" line="346"/>
+        <source>Please enter servings unit.</source>
+        <translation>Inserisci l&apos;unità di misura delle porzioni.</translation>
+    </message>
+    <message>
+        <location filename="../../edit_dialog.cc" line="349"/>
+        <source>Need at least one category.</source>
+        <translation>È necessaria almeno una categoria.</translation>
+    </message>
+    <message>
+        <location filename="../../edit_dialog.cc" line="352"/>
+        <source>Ingredient name must not be empty.</source>
+        <translation>Il nome dell&apos;ingrediente non può essere vuoto.</translation>
+    </message>
+    <message>
+        <location filename="../../edit_dialog.cc" line="355"/>
+        <source>Instruction section title must not be empty.</source>
+        <translation>Il titolo della sezione delle istruzioni non deve essere vuoto.</translation>
+    </message>
 </context>
 <context>
     <name>ExportDialog</name>
@@ -754,406 +862,538 @@
         <translation>&amp;Cerca</translation>
     </message>
     <message>
-        <location filename="../../main_window.ui" line="201"/>
+        <location filename="../../main_window.ui" line="211"/>
         <source>&amp;File</source>
         <translation>&amp;File</translation>
     </message>
     <message>
-        <location filename="../../main_window.ui" line="214"/>
+        <location filename="../../main_window.ui" line="224"/>
         <source>&amp;Help</source>
         <translation>&amp;Aiuto</translation>
     </message>
     <message>
-        <location filename="../../main_window.ui" line="221"/>
+        <location filename="../../main_window.ui" line="231"/>
         <source>Edit</source>
         <translation>Modifica</translation>
     </message>
     <message>
-        <location filename="../../main_window.ui" line="236"/>
+        <location filename="../../main_window.ui" line="241"/>
+        <source>Language</source>
+        <translation>Lingua</translation>
+    </message>
+    <message>
+        <location filename="../../main_window.ui" line="258"/>
         <source>Tool Bar</source>
         <translation>Barra degli strumenti</translation>
     </message>
     <message>
-        <location filename="../../main_window.ui" line="264"/>
+        <location filename="../../main_window.ui" line="286"/>
         <source>&amp;Quit</source>
         <translation>&amp;Esci</translation>
     </message>
     <message>
-        <location filename="../../main_window.ui" line="267"/>
+        <location filename="../../main_window.ui" line="289"/>
+        <location filename="../../main_window.ui" line="292"/>
         <source>Exit application</source>
         <translation>Esci dall&apos;applicazione</translation>
     </message>
     <message>
-        <location filename="../../main_window.ui" line="270"/>
+        <location filename="../../main_window.ui" line="295"/>
         <source>Ctrl+Q</source>
         <translation>Ctrl+Q</translation>
     </message>
     <message>
-        <location filename="../../main_window.ui" line="279"/>
+        <location filename="../../main_window.ui" line="304"/>
         <source>&amp;Import recipes</source>
         <translation>&amp;Importa le ricette</translation>
     </message>
     <message>
-        <location filename="../../main_window.ui" line="282"/>
+        <location filename="../../main_window.ui" line="307"/>
+        <location filename="../../main_window.ui" line="310"/>
         <source>Read MealMaster recipes from files</source>
         <translation>Leggi le ricette di MealMaster dai file</translation>
     </message>
     <message>
-        <location filename="../../main_window.ui" line="285"/>
+        <location filename="../../main_window.ui" line="313"/>
         <source>Ctrl+I</source>
         <translation>Ctrl+I</translation>
     </message>
     <message>
-        <location filename="../../main_window.ui" line="294"/>
+        <location filename="../../main_window.ui" line="322"/>
         <source>Print p&amp;review</source>
         <translation>Antep&amp;rima di stampa</translation>
     </message>
     <message>
-        <location filename="../../main_window.ui" line="297"/>
+        <location filename="../../main_window.ui" line="325"/>
+        <location filename="../../main_window.ui" line="328"/>
         <source>Print preview of current recipe</source>
         <translation>Anteprima di stampa della ricetta corrente</translation>
     </message>
     <message>
-        <location filename="../../main_window.ui" line="300"/>
+        <location filename="../../main_window.ui" line="331"/>
         <source>Ctrl+R</source>
         <translation>Ctrl+R</translation>
     </message>
     <message>
-        <location filename="../../main_window.ui" line="309"/>
+        <location filename="../../main_window.ui" line="340"/>
         <source>&amp;Print recipe</source>
         <translation>Stam&amp;pa la ricetta</translation>
     </message>
     <message>
-        <location filename="../../main_window.ui" line="312"/>
+        <location filename="../../main_window.ui" line="343"/>
+        <location filename="../../main_window.ui" line="346"/>
         <source>Print current recipe</source>
         <translation>Stampa la ricetta attuale</translation>
     </message>
     <message>
-        <location filename="../../main_window.ui" line="315"/>
+        <location filename="../../main_window.ui" line="349"/>
         <source>Ctrl+P</source>
         <translation>Ctrl+P</translation>
     </message>
     <message>
-        <location filename="../../main_window.ui" line="324"/>
+        <location filename="../../main_window.ui" line="358"/>
         <source>A&amp;bout AnyMeal</source>
         <translation>&amp;Riguardo a AnyMeal</translation>
     </message>
     <message>
-        <location filename="../../main_window.ui" line="327"/>
+        <location filename="../../main_window.ui" line="361"/>
+        <source>About AnyMeal</source>
+        <translation>Riguardo a AnyMeal</translation>
+    </message>
+    <message>
+        <location filename="../../main_window.ui" line="364"/>
         <source>Ctrl+B</source>
         <translation>Ctrl+B</translation>
     </message>
     <message>
-        <location filename="../../main_window.ui" line="336"/>
+        <location filename="../../main_window.ui" line="373"/>
         <source>&amp;Delete recipes</source>
         <translation>Cance&amp;lla le ricette</translation>
     </message>
     <message>
-        <location filename="../../main_window.ui" line="339"/>
+        <location filename="../../main_window.ui" line="376"/>
+        <location filename="../../main_window.ui" line="379"/>
         <source>Delete selected recipes</source>
         <translation>Cancella le ricette selezionate</translation>
     </message>
     <message>
-        <location filename="../../main_window.ui" line="342"/>
+        <location filename="../../main_window.ui" line="382"/>
         <source>Del</source>
         <translation>Canc</translation>
     </message>
     <message>
-        <location filename="../../main_window.ui" line="351"/>
+        <location filename="../../main_window.ui" line="391"/>
         <source>Exp&amp;ort recipes</source>
         <translation>Esp&amp;orta le ricette</translation>
     </message>
     <message>
-        <location filename="../../main_window.ui" line="354"/>
+        <location filename="../../main_window.ui" line="394"/>
+        <location filename="../../main_window.ui" line="397"/>
         <source>Write MealMaster recipes to file</source>
         <translation>Scrivi ricette MealMaster su file</translation>
     </message>
     <message>
-        <location filename="../../main_window.ui" line="357"/>
+        <location filename="../../main_window.ui" line="400"/>
         <source>Ctrl+O</source>
         <translation>Ctrl+O</translation>
     </message>
     <message>
-        <location filename="../../main_window.ui" line="366"/>
+        <location filename="../../main_window.ui" line="409"/>
         <source>&amp;Edit Recipe</source>
         <translation>Modifica la ric&amp;etta</translation>
     </message>
     <message>
-        <location filename="../../main_window.ui" line="369"/>
+        <location filename="../../main_window.ui" line="412"/>
+        <location filename="../../main_window.ui" line="415"/>
         <source>Edit current recipe</source>
         <translation>Modifica la ricetta corrente</translation>
     </message>
     <message>
-        <location filename="../../main_window.ui" line="372"/>
+        <location filename="../../main_window.ui" line="418"/>
         <source>Ctrl+E</source>
         <translation>Ctrl+E</translation>
     </message>
     <message>
-        <location filename="../../main_window.ui" line="381"/>
+        <location filename="../../main_window.ui" line="427"/>
         <source>Collect &amp;Garbage</source>
         <translation>Racco&amp;gli la spazzatura</translation>
     </message>
     <message>
-        <location filename="../../main_window.ui" line="384"/>
+        <location filename="../../main_window.ui" line="430"/>
+        <location filename="../../main_window.ui" line="433"/>
         <source>Delete unused categories and ingredients</source>
         <translation>Elimina le categorie e gli ingredienti inutilizzati</translation>
     </message>
     <message>
-        <location filename="../../main_window.ui" line="387"/>
+        <location filename="../../main_window.ui" line="436"/>
         <source>Ctrl+G</source>
         <translation>Ctrl+G</translation>
     </message>
     <message>
-        <location filename="../../main_window.ui" line="396"/>
+        <location filename="../../main_window.ui" line="445"/>
         <source>Add &amp;to Category</source>
         <translation>Aggiungi alla ca&amp;tegoria</translation>
     </message>
     <message>
-        <location filename="../../main_window.ui" line="399"/>
+        <location filename="../../main_window.ui" line="448"/>
+        <location filename="../../main_window.ui" line="451"/>
         <source>Add selected recipes to a category</source>
         <translation>Aggiungi le ricette selezionate a una categoria</translation>
     </message>
     <message>
-        <location filename="../../main_window.ui" line="402"/>
+        <location filename="../../main_window.ui" line="454"/>
         <source>Ctrl+T</source>
         <translation>Ctrl+T</translation>
     </message>
     <message>
-        <location filename="../../main_window.ui" line="411"/>
+        <location filename="../../main_window.ui" line="463"/>
         <source>&amp;Remove from Category</source>
         <translation>&amp;Rimuovi dalla Categoria</translation>
     </message>
     <message>
-        <location filename="../../main_window.ui" line="414"/>
+        <location filename="../../main_window.ui" line="466"/>
+        <source>Remove from Category</source>
+        <translation>Rimuovi dalla Categoria</translation>
+    </message>
+    <message>
+        <location filename="../../main_window.ui" line="469"/>
         <source>Ctrl+D</source>
         <translation>Ctrl+D</translation>
     </message>
     <message>
-        <location filename="../../main_window.ui" line="423"/>
+        <location filename="../../main_window.ui" line="478"/>
         <source>Open Co&amp;nverter Window</source>
         <translation>Aprire la finestra del co&amp;nvertitore</translation>
     </message>
     <message>
-        <location filename="../../main_window.ui" line="426"/>
+        <location filename="../../main_window.ui" line="481"/>
+        <source>Open Converter Window</source>
+        <translation>Aprire la finestra del convertitore</translation>
+    </message>
+    <message>
+        <location filename="../../main_window.ui" line="484"/>
         <source>Ctrl+U</source>
         <translation>Ctrl+U</translation>
     </message>
     <message>
-        <location filename="../../main_window.ui" line="453"/>
+        <location filename="../../main_window.ui" line="517"/>
         <source>Ctrl+N</source>
         <translation>Ctrl+N</translation>
     </message>
     <message>
-        <location filename="../../main_window.ui" line="435"/>
+        <location filename="../../main_window.ui" line="526"/>
+        <source>English</source>
+        <translation>Inglese</translation>
+    </message>
+    <message>
+        <location filename="../../main_window.ui" line="535"/>
+        <source>German</source>
+        <translation>Tedesca</translation>
+    </message>
+    <message>
+        <location filename="../../main_window.ui" line="544"/>
+        <source>French</source>
+        <translation>Francese</translation>
+    </message>
+    <message>
+        <location filename="../../main_window.ui" line="553"/>
+        <source>Italian</source>
+        <translation>Italiana</translation>
+    </message>
+    <message>
+        <location filename="../../main_window.ui" line="562"/>
+        <source>Slovenian</source>
+        <translation>Slovena</translation>
+    </message>
+    <message>
+        <location filename="../../main_window.ui" line="571"/>
+        <source>Dutch</source>
+        <translation>Olandese</translation>
+    </message>
+    <message>
+        <location filename="../../main_window.ui" line="493"/>
         <source>Remove duplicates</source>
         <translation>Rimuovere i duplicati</translation>
     </message>
     <message>
-        <location filename="../../main_window.ui" line="438"/>
+        <location filename="../../main_window.ui" line="496"/>
+        <location filename="../../main_window.ui" line="499"/>
         <source>Remove duplicates in selected recipes</source>
         <translation>Rimuovere i duplicati nelle ricette selezionate</translation>
     </message>
     <message>
-        <location filename="../../main_window.ui" line="447"/>
+        <location filename="../../main_window.ui" line="508"/>
         <source>New</source>
         <translation>Nuova</translation>
     </message>
     <message>
-        <location filename="../../main_window.ui" line="450"/>
+        <location filename="../../main_window.ui" line="511"/>
+        <location filename="../../main_window.ui" line="514"/>
         <source>New recipe</source>
         <translation>Nuova ricetta</translation>
     </message>
     <message>
-        <location filename="../../main_window.cc" line="92"/>
+        <location filename="../../main_window.cc" line="105"/>
         <source>Error Opening Database</source>
         <translation>Errore nell&apos;apertura del database</translation>
     </message>
     <message>
-        <location filename="../../main_window.cc" line="98"/>
+        <location filename="../../main_window.cc" line="184"/>
         <source>Showing %1 recipes ...</source>
         <translation>Mostrando %1 ricette ...</translation>
     </message>
     <message>
-        <location filename="../../main_window.cc" line="108"/>
+        <location filename="../../main_window.cc" line="194"/>
         <source>Import MealMaster Files</source>
         <translation>Importa File MealMaster</translation>
     </message>
     <message>
-        <location filename="../../main_window.cc" line="108"/>
-        <location filename="../../main_window.cc" line="438"/>
+        <location filename="../../main_window.cc" line="194"/>
+        <location filename="../../main_window.cc" line="568"/>
         <source>MealMaster (*.mm *.MM *.mmf *.MMF);;Text (*.txt *.TXT);;All files (*)</source>
         <translation>MealMaster (*.mm *.MM *.mmf *.MMF);;Testo (*.txt *.TXT);;Tutti i file (*)</translation>
     </message>
     <message>
-        <location filename="../../main_window.cc" line="114"/>
+        <location filename="../../main_window.cc" line="200"/>
         <source>Importing files ...</source>
         <translation>Importanto file ...</translation>
     </message>
     <message>
-        <location filename="../../main_window.cc" line="114"/>
-        <location filename="../../main_window.cc" line="445"/>
-        <location filename="../../main_window.cc" line="546"/>
+        <location filename="../../main_window.cc" line="200"/>
+        <location filename="../../main_window.cc" line="575"/>
+        <location filename="../../main_window.cc" line="676"/>
         <source>Cancel</source>
         <translation>Annulla</translation>
     </message>
     <message>
-        <location filename="../../main_window.cc" line="123"/>
+        <location filename="../../main_window.cc" line="210"/>
         <source>%1 imported and %2 failed ...</source>
         <translation>%1 importato e %2 fallito ...</translation>
     </message>
     <message>
-        <location filename="../../main_window.cc" line="137"/>
+        <location filename="../../main_window.cc" line="224"/>
         <source>Rejected recipe: </source>
         <translation>Ricetta rifiutata: </translation>
     </message>
     <message>
-        <location filename="../../main_window.cc" line="142"/>
-        <location filename="../../main_window.cc" line="469"/>
-        <location filename="../../main_window.cc" line="477"/>
+        <location filename="../../main_window.cc" line="229"/>
+        <location filename="../../main_window.cc" line="248"/>
+        <location filename="../../main_window.cc" line="599"/>
+        <location filename="../../main_window.cc" line="607"/>
         <source>Error writing to file </source>
         <translation>Errore nella scrittura del file </translation>
     </message>
     <message>
-        <location filename="../../main_window.cc" line="163"/>
+        <location filename="../../main_window.cc" line="259"/>
         <source>Recipes Imported</source>
         <translation>Ricette Importate</translation>
     </message>
     <message>
-        <location filename="../../main_window.cc" line="163"/>
+        <location filename="../../main_window.cc" line="259"/>
         <source>%1 imported and %2 failed.</source>
         <translation>%1 importato e %2 fallito.</translation>
     </message>
     <message>
-        <location filename="../../main_window.cc" line="167"/>
+        <location filename="../../main_window.cc" line="263"/>
         <source>Error While Importing</source>
         <translation>Errore durante l&apos;importazione</translation>
     </message>
     <message>
-        <location filename="../../main_window.cc" line="178"/>
+        <location filename="../../main_window.cc" line="274"/>
         <source>Edit current recipe, a copy of the recipe, a new recipe, or cancel?</source>
         <translation>Modificare la ricetta corrente, una copia della ricetta, una nuova ricetta o annullare?</translation>
     </message>
     <message>
-        <location filename="../../main_window.cc" line="179"/>
+        <location filename="../../main_window.cc" line="275"/>
         <source>&amp;Edit Current</source>
         <translation>Modifica corrent&amp;e</translation>
     </message>
     <message>
-        <location filename="../../main_window.cc" line="180"/>
+        <location filename="../../main_window.cc" line="276"/>
         <source>Edit C&amp;opy</source>
         <translation>Modifica c&amp;opia</translation>
     </message>
     <message>
-        <location filename="../../main_window.cc" line="181"/>
+        <location filename="../../main_window.cc" line="277"/>
         <source>Edit &amp;New</source>
         <translation>Modifica &amp;Nuovo</translation>
     </message>
     <message>
-        <location filename="../../main_window.cc" line="182"/>
+        <location filename="../../main_window.cc" line="278"/>
         <source>&amp;Cancel</source>
         <translation>&amp;Annulla</translation>
     </message>
     <message>
-        <location filename="../../main_window.cc" line="250"/>
+        <location filename="../../main_window.cc" line="306"/>
+        <source>Title</source>
+        <translation>Titolo</translation>
+    </message>
+    <message>
+        <location filename="../../main_window.cc" line="470"/>
+        <source>title</source>
+        <translation>titolo</translation>
+    </message>
+    <message>
+        <source>Category</source>
+        <translation type="vanished">Categoria</translation>
+    </message>
+    <message>
+        <location filename="../../main_window.cc" line="244"/>
+        <source>Unexpected end of file in %1</source>
+        <translation>Fine imprevista del file in %1</translation>
+    </message>
+    <message>
+        <location filename="../../main_window.cc" line="308"/>
+        <source>Servings</source>
+        <translation>Porzioni</translation>
+    </message>
+    <message>
+        <location filename="../../main_window.cc" line="357"/>
         <source>Error While Updating Recipe</source>
         <translation>Errore durante l&apos;aggiornamento della ricetta</translation>
     </message>
     <message>
-        <location filename="../../main_window.cc" line="275"/>
+        <location filename="../../main_window.cc" line="382"/>
         <source>Error Adding Recipes to Category</source>
         <translation>Errore nell&apos;aggiungere ricette alla categoria</translation>
     </message>
     <message>
-        <location filename="../../main_window.cc" line="301"/>
+        <location filename="../../main_window.cc" line="408"/>
         <source>Error Removing Recipes from Category</source>
         <translation>Errore nella rimozione delle ricette dalla categoria</translation>
     </message>
     <message>
-        <location filename="../../main_window.cc" line="320"/>
+        <location filename="../../main_window.cc" line="427"/>
         <source>Error Collecting Garbage</source>
         <translation>Errore nella raccolta della spazzatura</translation>
     </message>
     <message>
-        <location filename="../../main_window.cc" line="329"/>
+        <location filename="../../main_window.cc" line="436"/>
         <source>About AnyMeal %1</source>
         <translation>Riguardo a AnyMeal %1</translation>
     </message>
     <message>
-        <location filename="../../main_window.cc" line="374"/>
+        <location filename="../../main_window.cc" line="478"/>
+        <source>category</source>
+        <translation>categoria</translation>
+    </message>
+    <message>
+        <location filename="../../main_window.cc" line="481"/>
+        <source>not category</source>
+        <translation>non categoria</translation>
+    </message>
+    <message>
+        <location filename="../../main_window.cc" line="490"/>
+        <source>ingredient</source>
+        <translation>ingrediente</translation>
+    </message>
+    <message>
+        <location filename="../../main_window.cc" line="493"/>
+        <source>not ingredient</source>
+        <translation>non ingrediente</translation>
+    </message>
+    <message>
+        <location filename="../../main_window.cc" line="503"/>
         <source>Error Filtering Recipes</source>
         <translation>Errore filtraggio delle ricette</translation>
     </message>
     <message>
-        <location filename="../../main_window.cc" line="388"/>
+        <location filename="../../main_window.cc" line="518"/>
         <source>Error Resetting Selection</source>
         <translation>Errore ripristino della selezione</translation>
     </message>
     <message>
-        <location filename="../../main_window.cc" line="408"/>
+        <location filename="../../main_window.cc" line="538"/>
         <source>Error fetching recipe</source>
         <translation>Errore nel recupero della ricetta</translation>
     </message>
     <message>
-        <location filename="../../main_window.cc" line="438"/>
+        <location filename="../../main_window.cc" line="568"/>
         <source>Export MealMaster File</source>
         <translation>Esportare il File MealMaster</translation>
     </message>
     <message>
-        <location filename="../../main_window.cc" line="445"/>
+        <location filename="../../main_window.cc" line="575"/>
         <source>Exporting recipes ...</source>
         <translation>Esportando le ricette ...</translation>
     </message>
     <message>
-        <location filename="../../main_window.cc" line="464"/>
+        <location filename="../../main_window.cc" line="594"/>
         <source>Failed recipe: </source>
         <translation>Ricetta fallita:</translation>
     </message>
     <message>
-        <location filename="../../main_window.cc" line="480"/>
+        <location filename="../../main_window.cc" line="610"/>
         <source>%1 exported and %2 failed ...</source>
         <translation>%1 esportato e %2 fallito ...</translation>
     </message>
     <message>
-        <location filename="../../main_window.cc" line="483"/>
+        <location filename="../../main_window.cc" line="613"/>
         <source>Recipes Exported</source>
         <translation>Ricette esportate</translation>
     </message>
     <message>
-        <location filename="../../main_window.cc" line="483"/>
+        <location filename="../../main_window.cc" line="613"/>
         <source>%1 exported and %2 failed.</source>
         <translation>%1 esportato e %2 fallito.</translation>
     </message>
     <message>
-        <location filename="../../main_window.cc" line="487"/>
+        <location filename="../../main_window.cc" line="617"/>
         <source>Error While Exporting</source>
         <translation>Errore durante l&apos;esportazione</translation>
     </message>
     <message>
-        <location filename="../../main_window.cc" line="495"/>
+        <location filename="../../main_window.cc" line="625"/>
         <source>Delete Recipes</source>
         <translation>Cancella le ricette</translation>
     </message>
     <message>
-        <location filename="../../main_window.cc" line="495"/>
+        <location filename="../../main_window.cc" line="625"/>
         <source>Do you want to delete the selected recipes?</source>
         <translation>Vuoi cancellare le ricette selezionate?</translation>
     </message>
     <message>
-        <location filename="../../main_window.cc" line="514"/>
+        <location filename="../../main_window.cc" line="644"/>
         <source>Error Deleting Recipes</source>
         <translation>Errore nell&apos;eliminazione delle ricette</translation>
     </message>
     <message>
-        <location filename="../../main_window.cc" line="546"/>
+        <location filename="../../main_window.cc" line="676"/>
         <source>Detecting duplicates ...</source>
         <translation>Rilevamento duplicati ...</translation>
     </message>
     <message>
-        <location filename="../../main_window.cc" line="549"/>
+        <location filename="../../main_window.cc" line="679"/>
         <source>Found %1 duplicates ...</source>
         <translation>Trovati %1 duplicati ...</translation>
     </message>
 </context>
+<context>
+    <name>MergeDialog</name>
+    <message>
+        <location filename="../../merge_dialog.ui" line="14"/>
+        <source>Merge Category</source>
+        <translation>Unisci Categoria</translation>
+    </message>
+    <message>
+        <location filename="../../merge_dialog.ui" line="22"/>
+        <source>Merge Category Into:</source>
+        <translation>Unisci categoria in:</translation>
+    </message>
+</context>
+<context>
+    <name>RenameDialog</name>
+    <message>
+        <location filename="../../rename_dialog.ui" line="14"/>
+        <source>Rename Category</source>
+        <translation>Rinominare la Categoria</translation>
+    </message>
+    <message>
+        <location filename="../../rename_dialog.ui" line="22"/>
+        <source>Rename Category To:</source>
+        <translation>Rinominare la categoria in:</translation>
+    </message>
+</context>
 <context>
     <name>recipe</name>
     <message>
@@ -1162,32 +1402,32 @@
         <translation>Categorie</translation>
     </message>
     <message>
-        <location filename="../../html.cc" line="192"/>
+        <location filename="../../html.cc" line="195"/>
         <source>Yield</source>
         <translation>Resa</translation>
     </message>
     <message>
-        <location filename="../../html.cc" line="196"/>
+        <location filename="../../html.cc" line="199"/>
         <source>Ingredients</source>
         <translation>Ingredienti</translation>
     </message>
     <message>
-        <location filename="../../html.cc" line="199"/>
+        <location filename="../../html.cc" line="202"/>
         <source>amount</source>
         <translation>quantità</translation>
     </message>
     <message>
-        <location filename="../../html.cc" line="200"/>
+        <location filename="../../html.cc" line="203"/>
         <source>unit</source>
         <translation>unità</translation>
     </message>
     <message>
-        <location filename="../../html.cc" line="201"/>
+        <location filename="../../html.cc" line="204"/>
         <source>ingredient</source>
         <translation>ingrediente</translation>
     </message>
     <message>
-        <location filename="../../html.cc" line="221"/>
+        <location filename="../../html.cc" line="224"/>
         <source>Instructions</source>
         <translation>Istruzioni</translation>
     </message>
