@@ -18,6 +18,7 @@
 #include <sstream>
 #include <set>
 #include <unistd.h>
+#include <QtCore/QCoreApplication>
 #include <QtCore/QStandardPaths>
 #include <QtCore/QStringListModel>
 #include <QtWidgets/QFileDialog>
@@ -39,10 +40,13 @@
 using namespace std;
 
 MainWindow::MainWindow(QWidget *parent):
-  QMainWindow(parent), m_converter_window(this), m_import_dialog(this), m_export_dialog(this),
-  m_titles_model(NULL), m_categories_model(NULL), m_categories_completer(NULL)
+  QMainWindow(parent), m_translator(NULL), m_converter_window(this), m_import_dialog(this), m_export_dialog(this),
+  m_category_picker(this), m_titles_model(NULL), m_categories_model(NULL), m_category_table_model(NULL),
+  m_categories_completer(NULL)
 {
   m_ui.setupUi(this);
+  switch_language(QLocale::system().name().mid(0, 2));
+  m_ui.search_label->hide();
   connect(m_ui.action_new, &QAction::triggered, this, &MainWindow::new_recipe);
   connect(m_ui.action_import, &QAction::triggered, this, &MainWindow::import);
   connect(m_ui.action_delete, &QAction::triggered, this, &MainWindow::delete_recipes);
@@ -54,6 +58,12 @@ MainWindow::MainWindow(QWidget *parent):
   connect(m_ui.action_remove_from_category, &QAction::triggered, this, &MainWindow::remove_from_category);
   connect(m_ui.action_deduplicate, &QAction::triggered, this, &MainWindow::remove_duplicates);
   connect(m_ui.action_collect_garbage, &QAction::triggered, this, &MainWindow::collect_garbage);
+  connect(m_ui.action_lang_en, &QAction::triggered, this, &MainWindow::language_en);
+  connect(m_ui.action_lang_de, &QAction::triggered, this, &MainWindow::language_de);
+  connect(m_ui.action_lang_fr, &QAction::triggered, this, &MainWindow::language_fr);
+  connect(m_ui.action_lang_it, &QAction::triggered, this, &MainWindow::language_it);
+  connect(m_ui.action_lang_nl, &QAction::triggered, this, &MainWindow::language_nl);
+  connect(m_ui.action_lang_sl, &QAction::triggered, this, &MainWindow::language_sl);
   connect(m_ui.action_open_converter, &QAction::triggered, this, &MainWindow::open_converter);
   connect(m_ui.action_about, &QAction::triggered, this, &MainWindow::about);
   connect(m_ui.title_edit, &QLineEdit::returnPressed, this, &MainWindow::filter);
@@ -63,6 +73,7 @@ MainWindow::MainWindow(QWidget *parent):
   connect(m_ui.reset_button, &QPushButton::clicked, this, &MainWindow::reset);
   connect(m_ui.titles_view, &QListView::customContextMenuRequested, this, &MainWindow::titles_context_menu);
   connect(m_ui.recipe_browser, &QTextBrowser::customContextMenuRequested, this, &MainWindow::recipe_context_menu);
+  m_ui.category_edit->installEventFilter(this);
   m_titles_context_menu = new QMenu(this);
   m_titles_context_menu->addAction(m_ui.action_export);
   m_titles_context_menu->addAction(m_ui.action_edit);
@@ -80,10 +91,12 @@ MainWindow::MainWindow(QWidget *parent):
     QDir dir(path);
     dir.mkpath(dir.absolutePath());
     m_database.open(dir.filePath("anymeal.sqlite").toUtf8().constData());
+    switch_language(m_database.get_language(QLocale::system().name().mid(0, 2).toUtf8()).c_str());
     m_titles_model = new TitlesModel(this, &m_database);
     m_ui.titles_view->setModel(m_titles_model);
     connect(m_ui.titles_view->selectionModel(), &QItemSelectionModel::currentChanged, this, &MainWindow::selected);
     m_categories_model = new CategoriesModel(this, &m_database);
+    m_category_table_model = new CategoryTableModel(this, &m_database);
     m_categories_completer = new QCompleter(m_categories_model, this);
     m_categories_completer->setCaseSensitivity(Qt::CaseInsensitive);
     m_ui.category_edit->setCompleter(m_categories_completer);
@@ -94,6 +107,79 @@ MainWindow::MainWindow(QWidget *parent):
   };
 }
 
+void MainWindow::switch_language(const QString &country) {
+  if (m_translator) {
+    qApp->removeTranslator(m_translator);
+  } else {
+    m_translator = new QTranslator(this);
+  }
+#ifdef __MINGW32__
+  QString locale_dir = QString("locale/%1").arg(country);
+#else
+  QString app_dir = QCoreApplication::applicationDirPath();
+  QString locale_dir = QString("%1/../share/locale/%2/LC_MESSAGES").arg(app_dir).arg(country);
+#endif
+  if (m_translator->load("anymeal_qt", locale_dir)) {
+    qApp->installTranslator(m_translator);
+  }
+  m_ui.retranslateUi(this);
+  m_converter_window.m_ui.retranslateUi(&m_converter_window);
+  m_import_dialog.m_ui.retranslateUi(&m_import_dialog);
+  m_export_dialog.m_ui.retranslateUi(&m_export_dialog);
+  m_category_picker.m_ui.retranslateUi(&m_category_picker);
+  set_recipe(m_recipe);
+}
+
+void MainWindow::switch_and_set_language(const char *country) {
+  switch_language(country);
+  m_database.set_language(country);
+}
+
+void MainWindow::set_recipe(Recipe recipe) {
+  m_recipe = recipe;
+  m_ui.recipe_browser->setHtml(recipe_to_html(recipe, &translate).c_str());
+}
+
+void MainWindow::language_en(void)
+{
+  switch_and_set_language("en");
+}
+
+void MainWindow::language_de(void)
+{
+  switch_and_set_language("de");
+}
+
+void MainWindow::language_fr(void)
+{
+  switch_and_set_language("fr");
+}
+
+void MainWindow::language_it(void)
+{
+  switch_and_set_language("it");
+}
+
+void MainWindow::language_nl(void)
+{
+  switch_and_set_language("nl");
+}
+
+void MainWindow::language_sl(void)
+{
+  switch_and_set_language("sl");
+}
+
+bool MainWindow::eventFilter(QObject *object, QEvent *event) {
+  if (event->type() == QEvent::FocusIn) {
+    if (object == m_ui.category_edit) {
+      m_categories_completer->setCompletionPrefix(m_ui.category_edit->text());
+      m_categories_completer->complete();
+    }
+  }
+  return false;
+}
+
 void MainWindow::show_num_recipes(void) {
   statusBar()->showMessage(tr("Showing %1 recipes ...").arg(m_database.num_recipes()), 5000);
 }
@@ -117,7 +203,8 @@ void MainWindow::import(void) {
           m_database.begin();
           transaction = true;
           ifstream f(result.at(i).toUtf8().constData(), ifstream::binary);
-          vector<string> lst = recipes(f);
+          bool unexpected_eof = false;
+          vector<string> lst = recipes(f, &unexpected_eof);
           int c = 0;
           for (vector<string>::iterator recipe=lst.begin(); recipe!=lst.end(); recipe++) {
             progress.setLabelText(tr("%1 imported and %2 failed ...").arg(success).arg(failed));
@@ -152,6 +239,15 @@ void MainWindow::import(void) {
               transaction = false;
             };
             break;
+          } else if (unexpected_eof) {
+            failed++;
+            error_file << tr("Unexpected end of file in %1").arg(result.at(i)).toUtf8().constData() << "\r\n";
+            error_file.flush();
+            if (!error_file) {
+              ostringstream s;
+              s << tr("Error writing to file ").toUtf8().constData() << m_import_dialog.error_file();
+              throw gui_exception(s.str());
+            };
           };
           m_database.commit();
           transaction = false;
@@ -204,18 +300,28 @@ void MainWindow::edit(void) {
   edit_recipe(mode);
 }
 
+Recipe MainWindow::default_recipe(void)
+{
+  Recipe result;
+  result.set_title(tr("Title").toUtf8().constData());
+  result.set_servings(1);
+  result.set_servings_unit(tr("Servings").toUtf8().constData());
+  return result;
+}
+
 void MainWindow::edit_recipe(EditMode mode)
 {
-  Recipe recipe;
+  Recipe recipe = default_recipe();
   sqlite3_int64 recipe_id = 0;
   QModelIndex index = m_ui.titles_view->currentIndex();
   if (index.isValid() && mode != EDIT_NEW) {
     recipe_id = m_titles_model->recipeid(index);
     recipe = m_database.fetch_recipe(recipe_id);
   } else if (mode == EDIT_CURRENT)
-    return;
+    return;  // index is not valid, so can't edit current
   EditDialog edit_dialog(this);
   edit_dialog.set_recipe(recipe);
+  edit_dialog.set_category_table_model(m_category_table_model);
   if (edit_dialog.exec() == QDialog::Accepted) {
     Recipe result = edit_dialog.get_recipe();
     bool transaction = false;
@@ -230,15 +336,16 @@ void MainWindow::edit_recipe(EditMode mode)
         m_database.delete_recipes(ids);
       };
       sqlite3_int64 recipe_new_id = m_database.insert_recipe(result);
-      m_ui.recipe_browser->setHtml(recipe_to_html(result, &translate).c_str());
+      set_recipe(result);
       m_database.commit();
       QModelIndex idx;
       if (mode == EDIT_CURRENT) {
-        idx = m_titles_model->edit_entry(index, recipe_new_id, result.title().c_str());
+        idx = m_titles_model->edit_entry(index, recipe_new_id, result.title_c_str());
       } else {
-        idx = m_titles_model->add_entry(recipe_new_id, result.title().c_str());
+        idx = m_titles_model->add_entry(recipe_new_id, result.title_c_str());
       };
       m_ui.titles_view->setCurrentIndex(idx);
+      m_categories_model->reset();
       QGuiApplication::restoreOverrideCursor();
     } catch (exception &e) {
       try {
@@ -327,7 +434,7 @@ void MainWindow::open_converter(void) {
 
 void MainWindow::about(void) {
   QMessageBox::information(this, tr("About AnyMeal %1").arg(PACKAGE_VERSION), "AnyMeal recipe management software\n"
-      "Copyright © 2002 to 2023  Jan Wedekind\n\n"
+      "Copyright © 2002 to 2024  Jan Wedekind\n\n"
       "This program is free software: you can redistribute it and/or modify "
       "it under the terms of the GNU General Public License as published by "
       "the Free Software Foundation, either version 3 of the License, or "
@@ -340,29 +447,51 @@ void MainWindow::about(void) {
       "along with this program.  If not, see <https://www.gnu.org/licenses/>.");
 }
 
+void MainWindow::show_search_history(const char *type, const char *text)
+{
+  if (!m_ui.search_label->text().isEmpty())
+    m_ui.search_label->setText(QString(", ") + m_ui.search_label->text());
+  m_ui.search_label->setText(QString("<em>%1:</em>").arg(type) + text + m_ui.search_label->text());
+  m_ui.search_label->show();
+}
+
+void MainWindow::reset_search_history(void)
+{
+  m_ui.search_label->hide();
+  m_ui.search_label->setText("");
+}
+
 void MainWindow::filter(void) {
   try {
     QGuiApplication::setOverrideCursor(QCursor(Qt::WaitCursor));
+    m_ui.search_label->show();
     if (!m_ui.title_edit->text().isEmpty()) {
       m_database.select_by_title(m_ui.title_edit->text().toUtf8().constData());
+      show_search_history(tr("title").toUtf8().constData(), m_ui.title_edit->text().toUtf8().constData());
       m_titles_model->reset();
       m_categories_model->reset();
       m_ui.title_edit->setText("");
     };
     if (!m_ui.category_edit->text().isEmpty()) {
-      if (m_ui.with_category_radio->isChecked())
+      if (m_ui.with_category_radio->isChecked()) {
         m_database.select_by_category(m_ui.category_edit->text().toUtf8().constData());
-      else
+        show_search_history(tr("category").toUtf8().constData(), m_ui.category_edit->text().toUtf8().constData());
+      } else {
         m_database.select_by_no_category(m_ui.category_edit->text().toUtf8().constData());
+        show_search_history(tr("not category").toUtf8().constData(), m_ui.category_edit->text().toUtf8().constData());
+      };
       m_titles_model->reset();
       m_categories_model->reset();
       m_ui.category_edit->setText("");
     };
     if (!m_ui.ingredient_edit->text().isEmpty()) {
-      if (m_ui.with_ingredient_radio->isChecked())
+      if (m_ui.with_ingredient_radio->isChecked()) {
         m_database.select_by_ingredient(m_ui.ingredient_edit->text().toUtf8().constData());
-      else
+        show_search_history(tr("ingredient").toUtf8().constData(), m_ui.ingredient_edit->text().toUtf8().constData());
+      } else {
         m_database.select_by_no_ingredient(m_ui.ingredient_edit->text().toUtf8().constData());
+        show_search_history(tr("not ingredient").toUtf8().constData(), m_ui.ingredient_edit->text().toUtf8().constData());
+      };
       m_titles_model->reset();
       m_categories_model->reset();
       m_ui.ingredient_edit->setText("");
@@ -379,6 +508,7 @@ void MainWindow::reset(void) {
   try {
     QGuiApplication::setOverrideCursor(QCursor(Qt::WaitCursor));
     m_database.select_all();
+    reset_search_history();
     m_titles_model->reset();
     m_categories_model->reset();
     show_num_recipes();
@@ -398,7 +528,7 @@ void MainWindow::selected(const QModelIndex &current, const QModelIndex &) {
     QGuiApplication::setOverrideCursor(QCursor(Qt::WaitCursor));
     if (current.isValid()) {
       Recipe recipe = m_database.fetch_recipe(m_titles_model->recipeid(current));
-      m_ui.recipe_browser->setHtml(recipe_to_html(recipe, &translate).c_str());
+      set_recipe(recipe);
     } else {
       m_ui.recipe_browser->clear();
     };
