@@ -117,6 +117,16 @@ TEST(DatabaseTest, RecipeHeaderRoundtrip) {
   EXPECT_EQ("servings", result.servings_unit());
 }
 
+TEST(DatabaseTest, TestLongTitle) {
+  Database database;
+  database.open(":memory:");
+  Recipe recipe;
+  recipe.set_title("aaaaaaaaaaaaaaaaaaaaaaaaaaaa");
+  database.insert_recipe(recipe);
+  Recipe result = database.fetch_recipe(1);
+  EXPECT_EQ("aaaaaaaaaaaaaaaaaaaaaaaaaaaa", result.title());
+}
+
 TEST(DatabaseTest, CategoriesRoundtrip) {
   Database database;
   database.open(":memory:");
@@ -126,8 +136,10 @@ TEST(DatabaseTest, CategoriesRoundtrip) {
   database.insert_recipe(recipe);
   Recipe result = database.fetch_recipe(1);
   ASSERT_EQ(2, result.categories().size());
-  EXPECT_EQ("cakes", result.categories()[0]);
-  EXPECT_EQ("sweet", result.categories()[1]);
+  set<string>::iterator category = result.categories().begin();
+  EXPECT_EQ("cakes", *category);
+  category++;
+  EXPECT_EQ("sweet", *category);
 }
 
 TEST(DatabaseTest, IngredientRoundtrip) {
@@ -260,6 +272,40 @@ TEST(DatabaseTest, GetCategoriesOrderAlphabeticalWhenSameRecipeCount) {
   EXPECT_EQ("B", result[1]);
 }
 
+TEST(DatabaseTest, GetCategoriesAlphabeticalWithRecipeCount) {
+  Database database;
+  database.open(":memory:");
+  Recipe recipe1;
+  recipe1.add_category("A");
+  database.insert_recipe(recipe1);
+  Recipe recipe2;
+  recipe2.add_category("B");
+  database.insert_recipe(recipe2);
+  Recipe recipe3;
+  recipe3.add_category("B");
+  database.insert_recipe(recipe3);
+  vector<pair<string, int>> result = database.categories_and_counts();
+  ASSERT_EQ(2, result.size());
+  EXPECT_EQ("A", result[0].first);
+  EXPECT_EQ("B", result[1].first);
+  EXPECT_EQ(1, result[0].second);
+  EXPECT_EQ(2, result[1].second);
+}
+
+TEST(DatabaseTest, GetCategoriesWithZeroRecipes) {
+  Database database;
+  database.open(":memory:");
+  Recipe recipe;
+  recipe.add_category("A");
+  vector<sqlite3_int64> recipe_ids;
+  recipe_ids.push_back(database.insert_recipe(recipe));
+  database.delete_recipes(recipe_ids);
+  vector<pair<string, int>> result = database.categories_and_counts();
+  ASSERT_EQ(1, result.size());
+  EXPECT_EQ("A", result[0].first);
+  EXPECT_EQ(0, result[0].second);
+}
+
 TEST(DatabaseTest, SelectByCategory) {
   Database database;
   database.open(":memory:");
@@ -384,7 +430,7 @@ TEST(DatabaseTest, AddRecipeToCategory) {
   database.add_recipes_to_category(ids, "A");
   Recipe result = database.fetch_recipe(1);
   ASSERT_EQ(1, result.categories().size());
-  EXPECT_EQ("A", result.categories()[0]);
+  EXPECT_EQ("A", *result.categories().begin());
 }
 
 TEST(DatabaseTest, RemoveRecipeFromCategory) {
@@ -400,3 +446,101 @@ TEST(DatabaseTest, RemoveRecipeFromCategory) {
   Recipe result = database.fetch_recipe(1);
   ASSERT_EQ(0, result.categories().size());
 }
+
+TEST(DatabaseTest, RenameCategory) {
+  Database database;
+  database.open(":memory:");
+  Recipe recipe;
+  recipe.set_title("Recipe A");
+  recipe.add_category("A");
+  database.insert_recipe(recipe);
+  database.rename_category("A", "B");
+  Recipe result = database.fetch_recipe(1);
+  ASSERT_EQ(1, result.categories().size());
+  EXPECT_EQ("B", *result.categories().begin());
+}
+
+TEST(DatabaseTest, GetCategoryID) {
+  Database database;
+  database.open(":memory:");
+  Recipe recipe;
+  recipe.set_title("Recipe A");
+  recipe.add_category("A");
+  database.insert_recipe(recipe);
+  ASSERT_EQ(database.get_category_id("A"), 1);
+  ASSERT_EQ(database.get_category_id("C"), 0);
+}
+
+TEST(DatabaseTest, MergeIntoCategory) {
+  Database database;
+  database.open(":memory:");
+  Recipe recipe1;
+  recipe1.add_category("A");
+  database.insert_recipe(recipe1);
+  Recipe recipe2;
+  recipe2.add_category("B");
+  database.insert_recipe(recipe2);
+  Recipe recipe3;
+  recipe3.add_category("C");
+  database.insert_recipe(recipe3);
+  database.merge_category("B", "A");
+  Recipe result = database.fetch_recipe(1);
+  ASSERT_EQ(1, result.categories().size());
+  EXPECT_EQ("A", *result.categories().begin());
+  result = database.fetch_recipe(2);
+  ASSERT_EQ(1, result.categories().size());
+  EXPECT_EQ("A", *result.categories().begin());
+  result = database.fetch_recipe(3);
+  ASSERT_EQ(1, result.categories().size());
+  EXPECT_EQ("C", *result.categories().begin());
+}
+
+TEST(DatabaseTest, MergeWithRecipesInBothCategories) {
+  Database database;
+  database.open(":memory:");
+  Recipe recipe;
+  recipe.add_category("A");
+  recipe.add_category("B");
+  database.insert_recipe(recipe);
+  database.merge_category("B", "A");
+  Recipe result = database.fetch_recipe(1);
+  ASSERT_EQ(1, result.categories().size());
+  EXPECT_EQ("A", *result.categories().begin());
+}
+
+TEST(DatabaseTest, DeleteCategory) {
+  Database database;
+  database.open(":memory:");
+  Recipe recipe;
+  recipe.add_category("A");
+  recipe.add_category("B");
+  database.insert_recipe(recipe);
+  database.delete_category("A");
+  Recipe result = database.fetch_recipe(1);
+  ASSERT_EQ(1, result.categories().size());
+  EXPECT_EQ("B", *result.categories().begin());
+}
+
+TEST(DatabaseTest, CountCategory) {
+  Database database;
+  database.open(":memory:");
+  Recipe recipe1;
+  recipe1.add_category("A");
+  database.insert_recipe(recipe1);
+  Recipe recipe2;
+  recipe2.add_category("A");
+  database.insert_recipe(recipe2);
+  Recipe recipe3;
+  recipe3.add_category("B");
+  database.insert_recipe(recipe3);
+  ASSERT_EQ(2, database.count_recipes("A"));
+  ASSERT_EQ(1, database.count_recipes("B"));
+}
+
+TEST(DatabaseTest, LanguageSetting) {
+  Database database;
+  database.open(":memory:");
+  ASSERT_EQ("en", database.get_language("en"));
+  database.set_language("de");
+  ASSERT_EQ("de", database.get_language("en"));
+}
